@@ -787,14 +787,14 @@ QString QucsPowerCombiningTool::calcChebyLines(double RL, double Z0, double gamm
     {
         QMessageBox::warning(0, QObject::tr("Error"),
                              QObject::tr("Chebyshev weighting for N>7 is not available"));
-        return QString("");
+        return QString();
     }
     QString s;
     double sec_theta_m;// = cosh((1/(1.*N))*acosh((1/gamma)*fabs((RL-Z0)/(Z0+RL))) );
     //double sec_theta_m = cosh((1/(1.*N))*acosh(fabs(log(RL/Z0)/(2*gamma))) );
     (fabs(log(RL/Z0)/(2*gamma)) < 1) ? sec_theta_m = 0 : sec_theta_m = cosh((1/(1.*N))*acosh(fabs(log(RL/Z0)/(2*gamma))) );
 
-    double w[7]; // for msvc predefined size.
+    std::vector<double> w(N,0.0);
 
     switch(N)//The weights are calculated by equating the reflection coeffient formula to the N-th Chebyshev polinomial
     {
@@ -2065,7 +2065,7 @@ QString QucsPowerCombiningTool::ConvertLengthFromM(double len)
           return QString("%1 mm").arg(RoundVariablePrecision(conv));
   }
   }while(true);
-  return QString("");
+  return QString();
 }
 
 // Copied from Qucs misc class
