@@ -75,6 +75,7 @@ private slots:
   void slotStepEntered();
   void slotNumberEntered();
   void slotHHeaderClicked(int headerIdx);
+  void slotFillFromSpice();
 
 protected slots:
     void reject();
@@ -82,7 +83,8 @@ protected slots:
 
 private:
   QVBoxLayout *all;   // the mother of all widgets
-  QValidator  *Validator, *ValRestrict, *Validator2;
+  QValidator  *Validator, *ValRestrict, *Validator2,
+              *ValName;
   QRegularExpression     Expr;
   QIntValidator *ValInteger;
   QTableWidget  *prop;
@@ -91,12 +93,14 @@ private:
   QLabel      *Name, *Description;
   QPushButton *BrowseButt, *EditButt, *ButtAdd, *ButtRem;
   QPushButton *ButtUp, *ButtDown;
+  QPushButton *ButtFillFromSpice;
   QCheckBox   *disp;
   Component   *Comp;
   Schematic   *Doc;
   bool        changed;
   int         tx_Dist, ty_Dist;   // remember the text position
   bool        setAllVisible; // used for toggling visibility of properties
+  bool compIsSimulation;
  
   QLabel    *textType;
   QLabel    *textSim, *textParam, *textValues, *textStart, *textStop,
@@ -109,6 +113,11 @@ private:
 
   void updateCompPropsList(void);
   QStringList getSimulationList();
+
+  void fillPropsFromTable();
+  void recreatePropsFromTable();
+  bool propChanged(Property *pp, const QString &value, const bool display);
+  void updateProperty(Property *pp, const QString &value, const bool display);
 };
 
 #endif
