@@ -26,10 +26,8 @@ Digi_Source::Digi_Source()
   Description = QObject::tr("digital source");
 
   Lines.append(new qucs::Line(-10,  0,  0,  0,QPen(Qt::darkGreen,2)));
-  Lines.append(new qucs::Line(-20,-10,-10,  0,QPen(Qt::darkGreen,2)));
-  Lines.append(new qucs::Line(-20, 10,-10,  0,QPen(Qt::darkGreen,2)));
-  Lines.append(new qucs::Line(-35,-10,-20,-10,QPen(Qt::darkGreen,2)));
-  Lines.append(new qucs::Line(-35, 10,-20, 10,QPen(Qt::darkGreen,2)));
+  Polylines.append(new qucs::Polyline(
+    std::vector<QPointF>{{-35, 10}, {-20, 10}, {-10, 0}, {-20, -10}, {-35, -10}}, QPen(Qt::darkGreen,2, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin)));
   Lines.append(new qucs::Line(-35,-10,-35, 10,QPen(Qt::darkGreen,2)));
 
   Lines.append(new qucs::Line(-32, 5,-28, 5,QPen(Qt::darkGreen,2)));
@@ -92,13 +90,14 @@ QString Digi_Source::netlist()
   s += " "+Ports.first()->Connection->Name;
   
   // output all properties
-  Props.first();   // first property not needed
-  Property *pp = Props.next();
-  s += " "+pp->Name+"=\""+pp->Value+"\"";
-  pp = Props.next();
-  s += " "+pp->Name+"=\"["+pp->Value+"]\"";
-  pp = Props.next();
-  s += " "+pp->Name+"=\""+pp->Value+"\"\n";
+     // first property not needed
+  auto pp = Props.begin();
+  pp++;
+  s += " "+(*pp)->Name+"=\""+(*pp)->Value+"\"";
+  pp++;
+  s += " "+(*pp)->Name+"=\"["+(*pp)->Value+"]\"";
+  pp++;
+  s += " "+(*pp)->Name+"=\""+(*pp)->Value+"\"\n";
 
   return s;
 }
@@ -167,7 +166,8 @@ QString Digi_Source::verilogCode(int NumPorts)
       State = '1';
     s += "  always begin\n";
 
-    t = Props.next()->Value.section(';',z,z).trimmed();
+    QString pv = Props.at(2)->Value;
+    t = pv.section(';',z,z).trimmed();
     while(!t.isEmpty()) {
       if(!misc::Verilog_Delay(t, Name))
         return t;    // time has not VHDL format
@@ -175,11 +175,11 @@ QString Digi_Source::verilogCode(int NumPorts)
       s += "   " + t + ";\n";
       State ^= 1;
       z++;
-      t = Props.current()->Value.section(';',z,z).trimmed();
+      t = pv.section(';',z,z).trimmed();
     }
   }
   else {  // truth table simulation
-    int Num = Props.getFirst()->Value.toInt() - 1;    
+    int Num = Props.front()->Value.toInt() - 1;    
     s += "  always begin\n";
     s += "    " + r + " = 0;\n";
     s += "    #"+ QString::number(1 << Num) + ";\n";
