@@ -19,6 +19,7 @@
 #include "extsimkernels/spicecompat.h"
 #include "extsimkernels/verilogawriter.h"
 
+#include <QFontInfo>
 #include <QFontMetrics>
 
 Equation::Equation()
@@ -38,7 +39,7 @@ Equation::Equation()
   Lines.append(new qucs::Line(-xb, -yb, -xb,  yb,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line(-xb,  yb,  xb+3,yb,QPen(Qt::darkBlue,2)));
   Texts.append(new Text(-xb+4,  -yb-3, QObject::tr("Equation"),
-			QColor(0,0,0), 12.0));
+			QColor(0,0,0), QFontInfo(f).pixelSize()));
 
   x1 = -xb-3;  y1 = -yb-5;
   x2 =  xb+9; y2 =  yb+3;
@@ -62,7 +63,7 @@ QString Equation::verilogCode(int)
 {
   QString s;
   // output all equations
-  for(Property *pr = Props.first(); pr != 0; pr = Props.next())
+  for(Property *pr : Props)
     if(pr->Name != "Export")
       s += "  real "+pr->Name+"; initial "+pr->Name+" = "+pr->Value+";\n";
   return s;
@@ -73,7 +74,7 @@ QString Equation::vhdlCode(int)
 {
   QString s;
   // output all equations
-  for(Property *pr = Props.first(); pr != 0; pr = Props.next())
+  for(Property *pr : Props)
     if(pr->Name != "Export")
       s += "  constant "+pr->Name+" : time := "+pr->Value+";\n";
   return s;
@@ -86,7 +87,7 @@ Component* Equation::newOne()
 
 Element* Equation::info(QString& Name, char* &BitmapFile, bool getNewOne)
 {
-  Name = QObject::tr("Qucs legacy equation");
+  Name = QObject::tr("Qucsator equation");
   BitmapFile = (char *) "equation";
 
   if(getNewOne)  return new Equation();
@@ -96,7 +97,7 @@ Element* Equation::info(QString& Name, char* &BitmapFile, bool getNewOne)
 QString Equation::getVAvariables()
 {
     QStringList vars;
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         vars.append(Props.at(i)->Name);
     }
 
@@ -106,7 +107,7 @@ QString Equation::getVAvariables()
 QString Equation::getVAExpressions()
 {
     QString s;
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         QStringList tokens;
         spicecompat::splitEqn(Props.at(i)->Value,tokens);
         vacompat::convert_functions(tokens);
@@ -123,7 +124,7 @@ QString Equation::getVAExpressions()
  */
 QString Equation::getExpression(bool isXyce)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QStringList ng_vars,ngsims;
     getNgnutmegVars(ng_vars,ngsims);
@@ -137,7 +138,7 @@ QString Equation::getExpression(bool isXyce)
     QRegularExpression spicefp_pattern("^[\\+\\-]*\\d*\\.\\d+[A-Za-z]{,3}$"); // float and scaling suffix
     QRegularExpression spicedec_pattern("^[\\+\\-]*\\d+[A-Za-z]{,3}$"); // decimal and scaling suffix
 
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         QStringList tokens;
         QString eqn = Props.at(i)->Value;
         spicecompat::splitEqn(eqn,tokens);
@@ -171,14 +172,14 @@ QString Equation::getExpression(bool isXyce)
  */
 QString Equation::getEquations(QString sim, QStringList &dep_vars)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QStringList ng_vars,ngsims;
     getNgnutmegVars(ng_vars,ngsims);
 
     QString s;
     dep_vars.clear();
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         QStringList tokens;
         QString eqn = Props.at(i)->Value;
         spicecompat::splitEqn(eqn,tokens);
@@ -213,9 +214,9 @@ QString Equation::getNgspiceScript()
 
     QString s;
     s.clear();
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         QStringList tokens;
         QString eqn = Props.at(i)->Value;
         spicecompat::splitEqn(eqn,tokens);
@@ -239,7 +240,7 @@ void Equation::getNgnutmegVars(QStringList &vars, QStringList &sims)
 {
     vars.clear();
     sims.clear();
-    for (unsigned int i=0;i<Props.count()-1;i++) {
+    for (int i=0;i<Props.count()-1;i++) {
         QStringList tokens;
         QString eqn = Props.at(i)->Value;
         spicecompat::splitEqn(eqn,tokens);
