@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "hb_sim.h"
-#include "main.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 #include <QRegularExpression>
 
@@ -27,18 +25,7 @@ HB_Sim::HB_Sim()
   Simulator = spicecompat::simXyce | spicecompat::simQucsator;
 
   QString  s = Description;
-  int a = s.lastIndexOf(" ");
-  if (a != -1) s[a] = '\n';    // break line before the word "simulation"
-
-  Texts.append(new Text(0, 0, s.left(a), Qt::darkBlue, QucsSettings.largeFontSize));
-  if (a != -1)
-    Texts.append(new Text(0, 0, s.mid(a+1), Qt::darkBlue, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+163; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".HB";
   Name  = "HB";
   SpiceModel = ".HB";
