@@ -26,10 +26,11 @@
 MutualX::MutualX()
 {
   Description = QObject::tr("several mutual inductors");
-  Simulator = spicecompat::simQucsator;
+  Simulator = spicecompat::simAll;
 
   Model = "MUTX";
   Name  = "Tr";
+  SpiceModel = "K";
 
   const int init_coils=2; // initial number of coils
   // must be the first property!
@@ -152,15 +153,17 @@ void MutualX::createSymbol()
     int dCoils = abs(oldCoils - Num);          // how many coils were added/removed?
 
     if (oldCoils>Num) { // reduce coils number
-      for(int i = 0; i < dCoils; i++)
-        Props.remove(Num+1); // remove excess coils
+      for(int i = 0; i < dCoils; i++){
+        Props.removeAt(Num+1); // remove excess coils
+      }
+
       // remove only the no longer valid coupling coefficients, leave the
       //   ones related to existing coils untouched
       for(int i = 1,state=1; i < oldCoils; i++)
         for(int j = i+1; j <= oldCoils; j++,state++) {
             if ((i>Num)||(j>Num)) {
-                Props.remove(Num + state);
-                state--;
+              Props.removeAt(Num + state);
+              state--;
             }
         }
 
@@ -185,11 +188,12 @@ void MutualX::createSymbol()
   // in any case rewrite properties Name and Description
   // (when loading a component, added properties have a default name)
   // adjust coils names
-  Property * p1 = Props.at(1);
+  auto p1 = Props.begin();
+  ++p1;
   for(int i = 1; i <= Num; i++) {
-    p1->Name = "L"+QString::number(i);
-    p1->Description = QObject::tr("inductance of coil") + " " + QString::number(i);
-    p1 = Props.next();
+    (*p1)->Name = "L"+QString::number(i);
+    (*p1)->Description = QObject::tr("inductance of coil") + " " + QString::number(i);
+    p1++;
   }
   // adjust coupling coeffs names
   for(int i = 1,state=1; i < Num; i++) 
@@ -224,3 +228,35 @@ void MutualX::createSymbol()
     x += 14;
   }
 }
+
+QString MutualX::spice_netlist(bool isXyce)
+{
+    Q_UNUSED(isXyce);
+    int coils = getProperty("coils")->Value.toInt();
+
+    QString s;
+    for (int i = 0; i < coils; i++) {
+        QString li = "L" + Name + "_L" + QString::number(i+1);
+        QString prop_l = "L" + QString::number(i+1);
+        QString ind = spicecompat::normalize_value(getProperty(prop_l)->Value);
+        s += QString("%1 %2 %3 %4\n").arg(li)
+                .arg(spicecompat::normalize_node_name(Ports.at(2*i)->Connection->Name))
+                .arg(spicecompat::normalize_node_name(Ports.at(2*i+1)->Connection->Name))
+                .arg(ind);
+    }
+    for (int i = 0; i < coils; i++) {
+        for (int j = i; j < coils; j++) {
+            if (i == j) continue;
+            QString kij = "K" + Name + "_K"
+                    + QString::number(i+1) + QString::number(j+1);
+            QString li = "L" + Name + "_L" + QString::number(i+1);
+            QString lj = "L" + Name + "_L" + QString::number(j+1);
+            auto pp = getProperty("k" + QString::number(i+1) + QString::number(j+1));
+            if (pp == nullptr) continue;
+            QString val_k = spicecompat::normalize_value(pp->Value);
+            s += QString("%1 %2 %3 %4\n").arg(kij).arg(li).arg(lj).arg(val_k);
+        }
+    }
+    return s;
+
+}
