@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "param_sweep.h"
-#include "main.h"
-#include "qucs.h"
 #include "schematic.h"
 #include "misc.h"
 
@@ -25,18 +23,7 @@ Param_Sweep::Param_Sweep()
   Description = QObject::tr("Parameter sweep");
 
   QString  s = Description;
-  int a = s.lastIndexOf(" ");
-  if (a != -1) s[a] = '\n';    // break line
-
-  Texts.append(new Text(0, 0, s.left(a), Qt::darkBlue, QucsSettings.largeFontSize));
-  if (a != -1)
-    Texts.append(new Text(0, 0, s.mid(a+1), Qt::darkBlue, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+104; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".SW";
   Name  = "SW";
   SpiceModel = "*";
@@ -55,8 +42,6 @@ Param_Sweep::Param_Sweep()
 		QObject::tr("stop value for sweep")));
   Props.append(new Property("Points", "20", true,
 		QObject::tr("number of simulation steps")));
-  Props.append(new Property("SweepModel","false",false,
-                            "[true,false]"));
 }
 
 Param_Sweep::~Param_Sweep()
@@ -79,28 +64,24 @@ Element* Param_Sweep::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 void Param_Sweep::recreate(Schematic*)
 {
-  Property *pp = Props.at(1);
-  Props.next();
-  if((pp->Value == "list") || (pp->Value == "const")) {
+  if((Props.at(1)->Value == "list") || (Props.at(1)->Value == "const")) {
     // Call them "Symbol" to omit them in the netlist.
-    pp = Props.next();
-    pp->Name = "Symbol";
-    pp->display = false;
-    pp = Props.next();
-    pp->Name = "Symbol";
-    pp->display = false;
-    Props.next()->Name = "Values";
+    Props.at(3)->Name = "Symbol";
+    Props.at(3)->display = false;
+    Props.at(4)->Name = "Symbol";
+    Props.at(4)->display = false;
+    Props.at(5)->Name = "Values";
   }
   else {
-    Props.next()->Name = "Start";
-    Props.next()->Name = "Stop";
-    Props.next()->Name = "Points";
+    Props.at(3)->Name = "Start";
+    Props.at(4)->Name = "Stop";
+    Props.at(5)->Name = "Points";
   }
 }
 
 QString Param_Sweep::getNgspiceBeforeSim(QString sim, int lvl)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QString s,unit;
     QStringList parameter_list = getProperty("Param")->Value.split( this->param_split_str );
@@ -108,8 +89,9 @@ QString Param_Sweep::getNgspiceBeforeSim(QString sim, int lvl)
     QString type = getProperty("Type")->Value;
     QString step_var = parameter_list.begin()->toLower();// use first element name as variable name
     step_var.remove(QRegularExpression("[\\.\\[\\]@:]"));
-	
-    s = QString("let number_%1 = 0\n").arg(step_var);
+
+    s = "option interp\n";
+    s += QString("let number_%1 = 0\n").arg(step_var);
     if (lvl==0) s += QString("echo \"STEP %1.%2\" > spice4qucs.%3.cir.res\n").arg(sim).arg(step_var).arg(sim);
     else s += QString("echo \"STEP %1.%2\" > spice4qucs.%3.cir.res%4\n").arg(sim).arg(step_var).arg(sim).arg(lvl);
 
@@ -136,21 +118,21 @@ QString Param_Sweep::getNgspiceBeforeSim(QString sim, int lvl)
         stop = std::max(ostart,ostop);
 
         if(type == "lin") {
-            step = (stop-start)/points;
-            for (; start <= stop; start += step) {
+            step = (stop-start)/(points-1);
+            while ( points > 0 ) {
                 s += QString("%1 ").arg(start);
+                start += step;
+                points -= 1;
             }
         } else {
             start = log10(start);
             stop = log10(stop);
-            step = (stop - start)/points;
+            step = (stop - start)/(points - 1);
 
-            for(; start <= stop; start += step) {
+            while ( points > 0 ) {
                 s += QString("%1 ").arg(pow(10, start));
-            }
-
-            if (start - step < stop) {
-                s += QString("%1 ").arg(pow(10, stop));
+                start += step;
+                points -= 1;
             }
         }
     }
@@ -159,39 +141,24 @@ QString Param_Sweep::getNgspiceBeforeSim(QString sim, int lvl)
     for(constListIterator=parameter_list.begin(); constListIterator!=parameter_list.end();++constListIterator)
     {
         QString par = *constListIterator;
-
-        bool modelsweep = false; // Find component and its modelstring
         bool compfound = false;
-        QString mod,mod_par;
-
-        if (!par.contains('@')) {
-            QStringList par_lst = par.split('.',qucs::SkipEmptyParts);
-            if (par_lst.count()>1) {
-                mod_par = par_lst.at(1);
-                // Schematic *sch = (Schematic *) QucsMain->DocumentTab->currentPage();
-                Schematic *sch = getSchematic();
-                Component *pc = sch->getComponentByName(par_lst.at(0));
-                if (pc != NULL) {
-                    mod = pc->getSpiceNetlist().section('\n',1,1,QString::SectionSkipEmpty)
-                                            .section(' ',1,1,QString::SectionSkipEmpty);
-                    if (!mod.isEmpty()) modelsweep = true;
-                }
-            }
-        }
+        bool temper_sweep = false;
 
         Schematic *sch = getSchematic();
         Component *pc = sch->getComponentByName(getProperty("Param")->Value);
         if (pc != NULL) compfound = true;
         else compfound = false;
 
-        if (modelsweep) { // Model parameter sweep
-            s += QString("altermod %1 %2 = $%3_act%4").arg(mod).arg(mod_par).arg(step_var).arg(nline_char);
-        } else {
-            QString mswp = getProperty("SweepModel")->Value;
-            if (mswp == "true")
-                s += QString("altermod %1 = $%2_act%3").arg(par).arg(step_var).arg(nline_char);
-            else if (compfound) s += QString("alter %1 = $%2_act%3").arg(par).arg(step_var).arg(nline_char);
-            else s += QString("alterparam %1 = $%2_act%3reset%3").arg(par).arg(step_var).arg(nline_char);
+        if (step_var == "temp" || step_var == "temper") temper_sweep = true;
+
+        if (temper_sweep) { // Sweep temperature
+          s += QString("option temp = $%1_act%2").arg(step_var).arg(nline_char);
+        } else if (compfound) { // Sweep device
+          s += QString("alter %1 = $%2_act%3").arg(par).arg(step_var).arg(nline_char);
+        } else if (par.startsWith("@")) { // Sweep model
+          s += QString("altermod %1 = $%2_act%3").arg(par).arg(step_var).arg(nline_char);
+        } else { // Sweep .PARAM variable
+          s += QString("alterparam %1 = $%2_act%3reset%3").arg(par).arg(step_var).arg(nline_char);
         }
     }
     return s;
@@ -199,7 +166,7 @@ QString Param_Sweep::getNgspiceBeforeSim(QString sim, int lvl)
 
 QString Param_Sweep::getNgspiceAfterSim(QString sim, int lvl)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QString s;
     QStringList parameter_list = getProperty("Param")->Value.split( this->param_split_str );
@@ -249,7 +216,7 @@ QString Param_Sweep::spice_netlist(bool isXyce)
         stop *= fac;
         misc::str2num(getProperty("Points")->Value,points,unit,fac);
         points *= fac;
-        step = (stop-start)/points;
+        step = (stop-start)/(points-1);
     }
 
     if (Props.at(0)->Value.toLower().startsWith("dc")) {
@@ -265,19 +232,3 @@ QString Param_Sweep::spice_netlist(bool isXyce)
     return s.toLower();
 }
 
-// -------------------------------------------------------
-QString Param_Sweep::netlist()
-{
-  QString s = Model+":"+Name;
-
-  // output all node names
-  for (Port *p1 : Ports)
-    s += " "+p1->Connection->Name;   // node names
-
-  // output all properties
-  for(unsigned int i=0; i <= Props.count()-2; i++)
-    if(Props.at(i)->Name != "Symbol")
-      s += " "+Props.at(i)->Name+"=\""+Props.at(i)->Value+"\"";
-
-  return s + '\n';
-}
