@@ -10,23 +10,24 @@
 
 #include "potentiometer.h"
 #include "extsimkernels/spicecompat.h"
+#include "node.h"
 
 potentiometer::potentiometer()
 {
   Description = QObject::tr ("Potentiometer verilog device");
-  Simulator = spicecompat::simQucsator;
+  Simulator = spicecompat::simAll;
 
-  Props.append (new Property ("R_pot", "1e4", false,
+  Props.append (new Property ("R_pot", "10k", true,
     QObject::tr ("nominal device resistance")
     +" ("+QObject::tr ("Ohm")+")"));
-  Props.append (new Property ("Rotation", "120", false,
+  Props.append (new Property ("Rotation", "120", true,
     QObject::tr ("shaft/wiper arm rotation")
     +" ("+QObject::tr ("degrees")+")"));
   Props.append (new Property ("Taper_Coeff", "0", false,
     QObject::tr ("resistive law taper coefficient")));
   Props.append (new Property ("LEVEL", "1", false,
     QObject::tr ("device type selector")+" [1, 2, 3]"));
-  Props.append (new Property ("Max_Rotation", "240.0", false,
+  Props.append (new Property ("Max_Rotation", "240.0", true,
     QObject::tr ("maximum shaft/wiper rotation")
     +" ("+QObject::tr ("degrees")+")"));
   Props.append (new Property ("Conformity", "0.2", false,
@@ -51,13 +52,14 @@ potentiometer::potentiometer()
   tx = x1 + 8;
   ty = y2 + 4;
   Model = "potentiometer";
+  SpiceModel = "R";
   Name  = "POT";
 }
 
 Component * potentiometer::newOne()
 {
   potentiometer * p = new potentiometer();
-  p->Props.getFirst()->Value = Props.getFirst()->Value; 
+  p->Props.front()->Value = Props.front()->Value;
   p->recreate(0); 
   return p;
 }
@@ -80,8 +82,8 @@ void potentiometer::createSymbol()
   Lines.append(new qucs::Line( 30,-13,-30,-13,QPen(Qt::darkBlue,2)));
 
   // resistor
-  Lines.append(new qucs::Line(-40,  0, -25, 0,QPen(Qt::darkBlue,2)));
-  Lines.append(new qucs::Line(-25,  0, -20,-5,QPen(Qt::darkBlue,2)));
+  Lines.append(new qucs::Line(-40,  0, -25, 0,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line(-25,  0, -20,-5,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
   Lines.append(new qucs::Line(-20, -5, -15, 0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line(-15,  0, -10,-5,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line(-10, -5, -5,  0,QPen(Qt::darkBlue,2)));
@@ -90,8 +92,8 @@ void potentiometer::createSymbol()
   Lines.append(new qucs::Line(  5,  0, 10, -5,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 10, -5, 15,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 15,  0, 20, -5,QPen(Qt::darkBlue,2)));
-  Lines.append(new qucs::Line( 20, -5, 25,  0,QPen(Qt::darkBlue,2)));
-  Lines.append(new qucs::Line( 25,  0, 40,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new qucs::Line( 20, -5, 25,  0,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+  Lines.append(new qucs::Line( 25,  0, 40,  0,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::FlatCap)));
 
   // arrow
   Lines.append(new qucs::Line( -4, -9,  0, -5,QPen(Qt::darkBlue,2)));
@@ -108,3 +110,18 @@ void potentiometer::createSymbol()
   x1 = -40; y1 = -20;
   x2 =  40; y2 =  15;
 }
+
+QString potentiometer::spice_netlist(bool isXyce)
+{
+    Q_UNUSED(isXyce);
+    QString s;
+    QString R = spicecompat::normalize_value(getProperty("R_pot")->Value);
+    QString rot = spicecompat::normalize_value(getProperty("Rotation")->Value);
+    QString max_rot = spicecompat::normalize_value(getProperty("Max_Rotation")->Value);
+    QString pin1 = spicecompat::normalize_node_name(Ports.at(0)->Connection->Name);
+    QString pin2 = spicecompat::normalize_node_name(Ports.at(1)->Connection->Name);
+    QString pin3 = spicecompat::normalize_node_name(Ports.at(2)->Connection->Name);
+    s += QString("R%1_1 %2 %3 R='(%4)*(%5)/(%6)'\n").arg(Name).arg(pin1).arg(pin2).arg(R).arg(rot).arg(max_rot);
+    s += QString("R%1_2 %2 %3 R='(%4)*(1.0-(%5)/(%6))'\n").arg(Name).arg(pin2).arg(pin3).arg(R).arg(rot).arg(max_rot);
+    return s;
+}
