@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "resistor.h"
-#include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 #include "extsimkernels/verilogawriter.h"
 
@@ -39,7 +37,7 @@ Resistor::Resistor(bool european)
   // this must be the last property in the list !!!
   Props.append(new Property("Symbol", "european", false,
         QObject::tr("schematic symbol")+" [european, US]"));
-  if(!european)  Props.getLast()->Value = "US";
+  if(!european)  Props.back()->Value = "US";
 
   createSymbol();
   tx = x1+4;
@@ -52,7 +50,7 @@ Resistor::Resistor(bool european)
 // -------------------------------------------------------
 Component* Resistor::newOne()
 {
-  return new Resistor(Props.getLast()->Value != "US");
+  return new Resistor(Props.back()->Value != "US");
 }
 
 QString Resistor::spice_netlist(bool )
@@ -102,7 +100,7 @@ QString Resistor::va_code()
 // -------------------------------------------------------
 void Resistor::createSymbol()
 {
-  if(Props.getLast()->Value != "US") {
+  if(Props.back()->Value != "US") {
     Lines.append(new qucs::Line(-18, -9, 18, -9,QPen(Qt::darkBlue,2)));
     Lines.append(new qucs::Line( 18, -9, 18,  9,QPen(Qt::darkBlue,2)));
     Lines.append(new qucs::Line( 18,  9,-18,  9,QPen(Qt::darkBlue,2)));
@@ -112,13 +110,13 @@ void Resistor::createSymbol()
   }
   else {
     Lines.append(new qucs::Line(-30,  0,-18,  0,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line(-18,  0,-15, -7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line(-15, -7, -9,  7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line( -9,  7, -3, -7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line( -3, -7,  3,  7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line(  3,  7,  9, -7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line(  9, -7, 15,  7,QPen(Qt::darkBlue,2)));
-    Lines.append(new qucs::Line( 15,  7, 18,  0,QPen(Qt::darkBlue,2)));
+    Lines.append(new qucs::Line(-18,  0,-15, -7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line(-15, -7, -9,  7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line( -9,  7, -3, -7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line( -3, -7,  3,  7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line(  3,  7,  9, -7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line(  9, -7, 15,  7,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
+    Lines.append(new qucs::Line( 15,  7, 18,  0,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::RoundCap)));
     Lines.append(new qucs::Line( 18,  0, 30,  0,QPen(Qt::darkBlue,2)));
   }
 
