@@ -106,7 +106,7 @@ QString Source_ac::ngspice_netlist()
     double z0 = spicecompat::normalize_value(getProperty("Z")->Value).toDouble();
     double p = spicecompat::normalize_value(getProperty("P")->Value).toDouble();
     double vrms = sqrt(z0/1000.0)*pow(10, p/20.0);
-    double vamp = vrms*sqrt(2.0);
+    double vamp = 2.0*vrms*sqrt(2.0);
     QString f = spicecompat::normalize_value(getProperty("f")->Value);
 
     bool en_tran = true;
@@ -140,7 +140,7 @@ QString Source_ac::xyce_netlist()
     QString s_p = spicecompat::normalize_value(getProperty("P")->Value);
     double p = s_p.toDouble();
     double vrms = sqrt(z0/1000.0)*pow(10, p/20.0);
-    double vamp = vrms*sqrt(2.0);
+    double vamp = 2.0*vrms*sqrt(2.0);
 
     bool en_tran = true;
     if (getProperty("EnableTran")->Value == "true") {
@@ -177,7 +177,7 @@ QString Source_ac::netlist()
       s += " "+p1->Connection->Name;   // node names
 
     // output all properties
-    for(unsigned int i=0; i <= Props.count()-2; i++)
+    for(int i=0; i <= Props.count()-2; i++)
       if(Props.at(i)->Name != "EnableTran")
         s += " "+Props.at(i)->Name+"=\""+Props.at(i)->Value+"\"";
 
