@@ -15,33 +15,16 @@
  *                                                                         *
  ***************************************************************************/
 #include "sp_sim.h"
-#include "main.h"
 #include "misc.h"
 #include "schematic.h"
+#include "settings.h"
 
 
 SP_Sim::SP_Sim()
 {
   isSimulation = true;
   Description = QObject::tr("S parameter simulation");
-
-  QString s = Description;
-  int a = s.indexOf(" ");
-  int b = s.lastIndexOf(" ");
-  if (a != -1 && b != -1) {
-    if (a > (int) s.length() - b)  b = a;
-  }
-  if (b != -1) s[b] = '\n';
-
-  Texts.append(new Text(0, 0, s.left(b), Qt::darkBlue, QucsSettings.largeFontSize));
-  if (b != -1)
-    Texts.append(new Text(0, 0, s.mid(b+1), Qt::darkBlue, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+121; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".SP";
   Name  = "SP";
   SpiceModel = ".SP";
@@ -90,21 +73,18 @@ Element* SP_Sim::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 void SP_Sim::recreate(Schematic*)
 {
-  Property *pp = Props.first();
-  if((pp->Value == "list") || (pp->Value == "const")) {
+  if((Props.at(0)->Value == "list") || (Props.at(0)->Value == "const")) {
     // Call them "Symbol" to omit them in the netlist.
-    pp = Props.next();
-    pp->Name = "Symbol";
-    pp->display = false;
-    pp = Props.next();
-    pp->Name = "Symbol";
-    pp->display = false;
-    Props.next()->Name = "Values";
+    Props.at(1)->Name = "Symbol";
+    Props.at(1)->display = false;
+    Props.at(2)->Name = "Symbol";
+    Props.at(2)->display = false;
+    Props.at(3)->Name = "Values";
   }
   else {
-    Props.next()->Name = "Start";
-    Props.next()->Name = "Stop";
-    Props.next()->Name = "Points";
+    Props.at(1)->Name = "Start";
+    Props.at(2)->Name = "Stop";
+    Props.at(3)->Name = "Points";
   }
 }
 
@@ -124,7 +104,7 @@ int SP_Sim::getSPortsNumber()
 
 QStringList SP_Sim::getExtraVariables()
 {
-    switch (QucsSettings.DefaultSimulator) {
+    switch (_settings::Get().item<int>("DefaultSimulator")) {
         case spicecompat::simNgspice:
             return getNgspiceExtraVariables();
         case spicecompat::simXyce:
@@ -190,7 +170,7 @@ QString SP_Sim::getSweepString()
         misc::str2num(Props.at(2)->Value,Fstop,unit,fac);
         Fstop *= fac;
         double Nd = ceil(log10(Fstop/Fstart)); // number of decades
-        double Npd = ceil(Np/Nd); // points per decade
+        double Npd = ceil((Np - 1)/Nd); // points per decade
         s += QString("DEC %1 ").arg(Npd);
     } else {  // no need conversion
         s += QString("LIN %1 ").arg(Props.at(3)->Value);
