@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "spicedialog.h"
+#include "misc.h"
 #include "spicefile.h"
 #include "main.h"
 #include "qucs.h"
@@ -156,7 +157,7 @@ SpiceDialog::SpiceDialog(QucsApp* App_, SpiceFile *c, Schematic *d)
   changed = false;
 
   // insert all properties into the ListBox
-  Property *pp = Comp->Props.first();
+  auto pp = Comp->Props.at(0);
   FileEdit->setText(pp->Value);
   FileCheck->setChecked(pp->display);
   SimCheck->setChecked(Comp->Props.at(2)->Value == "yes");
@@ -225,15 +226,15 @@ void SpiceDialog::slotButtApply()
   }
 
   // apply all the new property values
-  Property *pp = Comp->Props.first();
-  if(pp->Value != FileEdit->text())
+  auto pp = Comp->Props.begin();
+  if((*pp)->Value != FileEdit->text())
   {
-    pp->Value = FileEdit->text();
+    (*pp)->Value = FileEdit->text();
     changed = true;
   }
-  if(pp->display != FileCheck->isChecked())
+  if((*pp)->display != FileCheck->isChecked())
   {
-    pp->display = FileCheck->isChecked();
+    (*pp)->display = FileCheck->isChecked();
     changed = true;
   }
 
@@ -245,26 +246,26 @@ void SpiceDialog::slotButtApply()
     }
     tmp += "_net" + PortsList->item(i)->text();   // chosen ports
   }
-  pp = Comp->Props.next();
-  if(pp->Value != tmp)
+  pp++;
+  if((*pp)->Value != tmp)
   {
-    pp->Value = tmp;
+    (*pp)->Value = tmp;
     changed = true;
   }
-  pp = Comp->Props.next();
-  if((pp->Value=="yes") != SimCheck->isChecked())
+  pp++;
+  if(((*pp)->Value=="yes") != SimCheck->isChecked())
   {
-    pp->Value = ((SimCheck->isChecked())? "yes" : "no");
+    (*pp)->Value = ((SimCheck->isChecked())? "yes" : "no");
     changed = true;
   }
-  if(pp->Value != "yes") {
+  if((*pp)->Value != "yes") {
     Comp->withSim = false;
   }
 
-  pp = Comp->Props.next();
-  if(pp->Value != PrepCombo->currentText())
+  pp++;
+  if((*pp)->Value != PrepCombo->currentText())
   {
-    pp->Value = PrepCombo->currentText();
+    (*pp)->Value = PrepCombo->currentText();
     changed = true;
   }
 
@@ -278,28 +279,64 @@ void SpiceDialog::slotButtApply()
 // -------------------------------------------------------------------------
 void SpiceDialog::slotButtBrowse()
 {
-  QString s = QFileDialog::getOpenFileName(this,
-                  tr("Select a file"),
-                  lastDir.isEmpty() ? QString(".") : lastDir,
-                  tr("SPICE netlist") + QString(" (") + QucsSettings.spiceExtensions.join(" ") + QString(");;")
-                      + tr("All Files") + " (*.*)");
+  // current file name from the component properties
+  QString currFileName = FileEdit->text();
+  QFileInfo currFileInfo(currFileName);
+  // name of the schematic where component is instantiated (may be empty)
+  QFileInfo schematicFileInfo = Comp->getSchematic()->getFileInfo();
+  QString schematicFileName = schematicFileInfo.fileName();
+  // directory to use for the file open dialog
+  QString currDir;
 
-  if(s.isEmpty()) {
-    return;
+  if (!currFileName.isEmpty()) { // a file name is already defined
+    if (currFileInfo.isRelative()) { // but has no absolute path
+      if (!schematicFileName.isEmpty()) // if schematic has a filename
+        currDir = schematicFileInfo.absolutePath();
+      else    // use the WorkDir path
+        currDir = lastDir.isEmpty() ? QucsSettings.QucsWorkDir.absolutePath() : lastDir; 
+    } else {  // current file name is absolute
+      currDir = currFileInfo.exists() ? currFileInfo.absolutePath() : QucsSettings.QucsWorkDir.absolutePath();
+    }
+  } else {    // a file name is not defined
+    if (!schematicFileName.isEmpty()) { // if schematic has a filename
+      currDir = schematicFileInfo.absolutePath();
+    } else {  // use the WorkDir path
+      currDir = lastDir.isEmpty() ? QucsSettings.QucsWorkDir.absolutePath() : lastDir; 
+    }
   }
 
-  QFileInfo Info(s);
-  lastDir = Info.absolutePath();  // remember last directory
+  QString s = QFileDialog::getOpenFileName (
+      this,
+      tr("Select a file"),
+      currDir,
+      tr("SPICE netlist") + QString(" (") + QucsSettings.spiceExtensions.join(" ") + QString(");;")
+      + tr("All Files") + " (*.*)");
 
-  // snip path if file in current directory
-  if(QucsSettings.QucsWorkDir.exists(Info.fileName()) &&
-          QucsSettings.QucsWorkDir.absolutePath() == Info.absolutePath()) {
-    s = Info.fileName();
+  if(!s.isEmpty()) {
+    // snip path if file in current directory
+    QFileInfo file(s);
+    lastDir = file.absolutePath();
+
+    if (!schematicFileName.isEmpty()) {
+      currDir = schematicFileInfo.canonicalPath();
+    }
+
+    if (!(schematicFileName.isEmpty() &&
+          QucsMain->ProjName.isEmpty())) {
+      // unsaved schematic outside project; only absolute file name
+      // the schematic could be saved elsewhere and working directory may be changed
+      if ( file.canonicalFilePath().startsWith(currDir) ) {
+        s = QDir(currDir).relativeFilePath(s);
+      } else if(QucsSettings.QucsWorkDir.exists(file.fileName()) &&
+                 QucsSettings.QucsWorkDir.absolutePath() == file.absolutePath()) {
+        s = file.fileName();
+      }
+    }
+
+    FileEdit->setText(s);
+    Comp->Props.at(1)->Value = "";
+    loadSpiceNetList(s);
   }
-  FileEdit->setText(s);
-
-  Comp->Props.at(1)->Value = "";
-  loadSpiceNetList(s);
 }
 
 // -------------------------------------------------------------------------
@@ -318,7 +355,8 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
 {
   Comp->withSim = false;
   if(s.isEmpty()) return false;
-  QFileInfo FileInfo(QucsSettings.QucsWorkDir, s);
+  QString absFileName = misc::properAbsFileName(s, Doc);
+  QFileInfo FileInfo(QucsSettings.QucsWorkDir, absFileName);
 
   NodesList->clear();
   PortsList->clear();
@@ -331,7 +369,7 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
     qDebug() << "Run spice preprocessor (perl)";
     bool piping = true;
     QString script;
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
     QString interpreter = "tinyperl.exe";
 #else
     QString interpreter = "perl";
@@ -358,7 +396,7 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
     spiceArgs.append(FileInfo.filePath());
 
     QFile PrepFile;
-    QFileInfo PrepInfo(QucsSettings.QucsWorkDir, s + ".pre");
+    QFileInfo PrepInfo(QucsSettings.QucsWorkDir, absFileName + ".pre");
     QString PrepName = PrepInfo.filePath();
 
     if (!piping)
@@ -420,7 +458,7 @@ bool SpiceDialog::loadSpiceNetList(const QString& s)
         QMessageBox::critical(this, tr("SPICE Preprocessor Error"), Error);
         return false;
     }
-    FileInfo = QFileInfo(QucsSettings.QucsWorkDir, s + ".pre");
+    FileInfo = QFileInfo(QucsSettings.QucsWorkDir, absFileName + ".pre");
   }
 
   if (QucsSettings.DefaultSimulator == spicecompat::simQucsator) {
@@ -606,7 +644,7 @@ void SpiceDialog::slotGetNetlist()
 // -------------------------------------------------------------------------
 void SpiceDialog::slotButtEdit()
 {
-  Doc->App->editFile(QucsSettings.QucsWorkDir.filePath(FileEdit->text()));
+  Doc->App->editFile(misc::properAbsFileName(FileEdit->text(), Doc));
 }
 
 // -------------------------------------------------------------------------
