@@ -32,8 +32,8 @@
 #include <QStatusBar>
 
 #include "spicefile.h"
-#include "schematic.h"
 #include "main.h"
+#include "node.h"
 #include "qucs.h"
 #include "misc.h"
 #include "extsimkernels/spicecompat.h"
@@ -154,7 +154,7 @@ void SpiceFile::createSymbol()
 QString SpiceFile::netlist()
 {
   if(Props.at(1)->Value.isEmpty())
-    return QString("");  // no ports, no subcircuit instance
+    return QString();  // no ports, no subcircuit instance
 
   QString s = "Sub:"+Name;   // SPICE netlist is subcircuit
   for (Port *pp : Ports)
@@ -168,108 +168,7 @@ QString SpiceFile::netlist()
 // -------------------------------------------------------
 QString SpiceFile::getSubcircuitFile()
 {
-  // construct full filename
-  QString FileName = Props.getFirst()->Value;
-
-  if (FileName.isEmpty())
-  {
-      return misc::properAbsFileName(FileName);
-  }
-
-  QFileInfo FileInfo(FileName);
-
-  if (FileInfo.exists())
-  {
-      // the file must be an absolute path to a schematic file
-     return FileInfo.absoluteFilePath();
-  }
-  else
-  {
-    // get the complete base name (everything except the last '.'
-    // and whatever follows
-    QString baseName = FileInfo.completeBaseName();
-
-    // if only a file name is supplied, first check if it is in the
-    // same directory as the schematic file it is a part of
-    if (FileInfo.fileName () == FileName)
-    {
-        // the file has no path information, just the file name
-        if (containingSchematic)
-        {
-            // check if a file of the same name is in the same directory
-            // as the schematic file, if we have a pointer to it, in
-            // which case we use this one
-            QFileInfo schematicFileInfo = containingSchematic->getFileInfo ();
-
-            QString native_ext = FileInfo.suffix();
-            if (!native_ext.isEmpty()) {
-                QFileInfo localFileInfo (schematicFileInfo.canonicalPath ()
-                                         + "/" + baseName + "." + native_ext);
-                if (localFileInfo.exists()) {
-                    return localFileInfo.absoluteFilePath();
-                }
-            }
-            // if no extension given guess default extension
-            for (int i = 0; i < QucsSettings.spiceExtensions.count (); i++)
-            {
-                QString extension = QucsSettings.spiceExtensions[i];
-                extension.remove(0, 1); // take leading '*' out, issue with exits()
-
-                QFileInfo localFileInfo (schematicFileInfo.canonicalPath ()
-                                         + "/" + baseName + extension);
-
-                if (localFileInfo.exists ())
-                {
-                    // return the subcircuit saved in the same directory
-                    // as the schematic file
-                    return localFileInfo.absoluteFilePath();
-                }
-                else
-                {
-                    /// \todo improve GUI/CLI error/warning
-                    qCritical() << "Spice file not found:" << localFileInfo.absoluteFilePath();
-                }
-            }
-        }
-    }
-
-    // look up the hash table for the schematic file as
-    // it does not seem to be an absolute path, this will also
-    // search the home directory which is always hashed
-    QMutex mutex;
-    mutex.lock();
-    QString hashsearchresult = "";
-    // if GUI is running and has something in the hash
-    if ( (QucsMain != 0) && !QucsMain->spiceNameHash.isEmpty() )
-      hashsearchresult = QucsMain->spiceNameHash.value(baseName);
-    mutex.unlock();
-
-    if (hashsearchresult.isEmpty())
-    {
-        // the schematic was not found in the hash table, return
-        // what would always have been returned in this case
-        return misc::properAbsFileName(FileName);
-    }
-    else
-    {
-        // we found an entry in the hash table, check it actually still exists
-        FileInfo.setFile(hashsearchresult);
-
-        if (FileInfo.exists())
-        {
-            // it does exist so return the absolute file path
-            return FileInfo.absoluteFilePath();
-        }
-        else
-        {
-            // the schematic file does not actually exist, return
-            // what would always have been returned in this case
-            return misc::properAbsFileName(FileName);
-        }
-    }
-
-  }
-
+  return misc::properAbsFileName(Props.front()->Value, containingSchematic);
 }
 
 // -------------------------------------------------------------------------
@@ -365,7 +264,7 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
   if (preprocessor != "none") {
     bool piping = true;
     QStringList script;
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
     QString interpreter = "tinyperl.exe";
 #else
     QString interpreter = "perl";
@@ -489,7 +388,7 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
   (*filstream) << NetText;
 
   // only interact with the GUI if it was launched
-  if (QucsMain) {
+  if (QucsMain != nullptr) {
     QucsMain->statusBar()->showMessage(tr("Converting SPICE file \"%1\".").arg(*SpiceFile), 2000);
   }
   else
