@@ -17,7 +17,6 @@
 
 #include "volt_ac.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -25,13 +24,17 @@ Volt_ac::Volt_ac()
 {
   Description = QObject::tr("ideal ac voltage source");
 
-  Arcs.append(new qucs::Arc(-12,-12, 24, 24,     0, 16*360,QPen(Qt::darkBlue,2)));
-  Arcs.append(new qucs::Arc( -3, -7,  7,  7,16*270, 16*180,QPen(Qt::darkBlue,2)));
-  Arcs.append(new qucs::Arc( -3,  0,  7,  7, 16*90, 16*180,QPen(Qt::darkBlue,2)));
+  Ellipses.append(new qucs::Ellips(-12,-12, 24, 24,QPen(Qt::darkBlue,2)));
+  // wave
+  Arcs.append(new qucs::Arc( -3, -7,  7,  7,16*270, 16*180,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::FlatCap)));
+  Arcs.append(new qucs::Arc( -3,  0,  7,  7, 16*90, 16*180,QPen(Qt::darkBlue,2, Qt::SolidLine, Qt::FlatCap)));
+  // contacts
   Lines.append(new qucs::Line(-30,  0,-12,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 30,  0, 12,  0,QPen(Qt::darkBlue,2)));
+  // plus sign
   Lines.append(new qucs::Line( 18,  5, 18, 11,QPen(Qt::red,1)));
   Lines.append(new qucs::Line( 21,  8, 15,  8,QPen(Qt::red,1)));
+  // minus sign
   Lines.append(new qucs::Line(-18,  5,-18, 11,QPen(Qt::black,1)));
 
   Ports.append(new Port( 30,  0));
@@ -117,7 +120,7 @@ QString Volt_ac::netlist()
     s += " "+p1->Connection->Name;   // node names
 
   // output all properties
-  for(unsigned int i=0; i <= Props.count()-3; i++)
+  for(int i=0; i <= Props.count()-3; i++)
     if(Props.at(i)->Name != "Symbol")
       s += " "+Props.at(i)->Name+"=\""+Props.at(i)->Value+"\"";
 
