@@ -27,6 +27,7 @@
 #include "main.h"
 #include "../paintings/id_text.h"
 #include "dialogs/sweepdialog.h"
+#include "components/subcircuit.h"
 
 
 #include <QPlainTextEdit>
@@ -49,6 +50,7 @@ AbstractSpiceKernel::AbstractSpiceKernel(Schematic *sch_, QObject *parent) :
 {
     Sch = sch_;
     console = nullptr;
+    needsPrefix = false;
 
     if (Sch->showBias == 0) DC_OP_only = true;
     else DC_OP_only = false;
@@ -69,7 +71,7 @@ AbstractSpiceKernel::AbstractSpiceKernel(Schematic *sch_, QObject *parent) :
     SimProcess->setProcessChannelMode(QProcess::MergedChannels);
     connect(SimProcess,SIGNAL(finished(int)),this,SLOT(slotFinished()));
     connect(SimProcess,SIGNAL(readyRead()),this,SLOT(slotProcessOutput()));
-    connect(SimProcess,SIGNAL(error(QProcess::ProcessError)),this,SLOT(slotErrors(QProcess::ProcessError)));
+    connect(SimProcess,SIGNAL(errorOccurred(QProcess::ProcessError)),this,SLOT(slotErrors(QProcess::ProcessError)));
     connect(this,SIGNAL(destroyed()),this,SLOT(killThemAll()));
 
 }
@@ -196,21 +198,6 @@ void AbstractSpiceKernel::startNetlist(QTextStream &stream, bool xyce)
             }
         }
 
-        QStringList incls;
-        // Include Directives
-        for(Component *pc = Sch->DocComps.first(); pc != 0; pc = Sch->DocComps.next()) {
-            if ((pc->SpiceModel==".INCLUDE")||
-                (pc->SpiceModel==".LIB")||
-                (pc->Model=="SpLib")) {
-                s = pc->getSpiceModel();
-                if (!incls.contains(s)) {
-                    // prevent multiple libraries inclusion
-                    incls.append(s);
-                    stream<<s;
-                }
-            }
-        }
-
         // create .IC from wire labels
         QStringList wire_labels;
         for(Wire *pw = Sch->DocWires.first(); pw != 0; pw = Sch->DocWires.next()) {
@@ -1532,3 +1519,29 @@ bool AbstractSpiceKernel::waitEndOfSimulation()
     return SimProcess->waitForFinished(10000);
 }
 
+QString AbstractSpiceKernel::collectSpiceLibs(Schematic* sch)
+{
+  QStringList collected_spicelib;
+  for(Component *pc = sch->DocComps.first(); pc != 0; pc = sch->DocComps.next()) {
+    if (pc->Model == "Sub") {
+      Schematic *sub = new Schematic(0, ((Subcircuit *)pc)->getSubcircuitFile());
+      if(!sub->loadDocument())      // load document if possible
+      {
+        delete sub;
+        continue;
+      }
+      QString libstr = collectSpiceLibs(sub);
+      if (!collected_spicelib.contains(libstr)) {
+        collected_spicelib.append(libstr);
+      }
+      delete sub;
+    } else {
+      QString libstr = pc->getSpiceLibrary();
+      if (!collected_spicelib.contains(libstr)) {
+        collected_spicelib.append(libstr);
+      }
+    }
+  }
+  return collected_spicelib.join("");
+}
+
