@@ -17,7 +17,6 @@
 
 
 #include "ngspice.h"
-#include "xspice_cmbuilder.h"
 #include "components/iprobe.h"
 #include "components/vprobe.h"
 #include "components/equation.h"
@@ -28,6 +27,8 @@
 #include "main.h"
 #include "misc.h"
 #include "qucs.h"
+#include "settings.h"
+
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -70,7 +71,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
 {
     Q_UNUSED(simulations);
 
-    if(!prepareSpiceNetlist(stream)) return; // Unable to perform spice simulation
+    stream << "* Qucs " << PACKAGE_VERSION << "  " << Sch->DocName << "\n";
 
     // include math. functions for inter-simulator compat.
     QString mathf_inc;
@@ -79,6 +80,8 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
     if (found && QucsSettings.DefaultSimulator != spicecompat::simSpiceOpus)
         stream<<QString(".INCLUDE \"%1\"\n").arg(mathf_inc);
 
+    stream<<collectSpiceLibs(Sch); // collect libraries on the top of netlist
+    if(!prepareSpiceNetlist(stream)) return; // Unable to perform spice simulation
     startNetlist(stream); // output .PARAM and components
 
     if (DC_OP_only) {
@@ -123,24 +126,26 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
 
     stream << "\n.control\n\n";          //execute simulations
 
-    if (!QucsMain->ProjName.isEmpty()) {
-        // always load osdi from the project directory
-        QStringList osdi_ext;
-        osdi_ext<<"*.osdi";
-        QStringList osdi_files = QucsSettings.QucsWorkDir.entryList(osdi_ext,QDir::Files);
-        for(const auto &file : osdi_files) {
-            QString abs_file = QucsSettings.QucsWorkDir.absolutePath() +
-                               QDir::separator() + file;
-            stream<<QString("pre_osdi '%1'\n").arg(abs_file);
+    if (QucsMain != nullptr) { // if not run from CLI
+        if (!QucsMain->ProjName.isEmpty()) {
+            // always load osdi from the project directory
+            QStringList osdi_ext;
+            osdi_ext<<"*.osdi";
+            QStringList osdi_files = QucsSettings.QucsWorkDir.entryList(osdi_ext,QDir::Files);
+            for(const auto &file : osdi_files) {
+                QString abs_file = QucsSettings.QucsWorkDir.absolutePath() +
+                        QDir::separator() + file;
+                stream<<QString("pre_osdi '%1'\n").arg(abs_file);
+            }
         }
     }
 
     // determine which simulations are in use
     unsigned int dcSims = 0;
-    unsigned int dcswpSims = 0;
     unsigned int freqSims = 0;
     unsigned int timeSims = 0;
     unsigned int fourSims = 0;
+    unsigned int pzSims = 0;
 
     outputs.clear();
     for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
@@ -168,7 +173,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         QString nods;
         for (const QString& nod : vars) {
             if ( nod.endsWith("#branch") )
-                nods.append(QString("%1 ").arg(nod));
+                nods.append(QString("i(%1) ").arg(nod.section('#', 0, 0)));
             else
                 nods.append(QString("v(%1) ").arg(nod));
         }
@@ -212,11 +217,39 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
                 }
             }
         } else if ( sim_typ == ".CUSTOMSIM" ) {
-            dcSims++; dcswpSims++; freqSims++; timeSims++; fourSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
             nods = pc->Props.at(1)->Value;
             nods.replace(';', ' ');
             outputs.append(pc->Props.at(2)->Value.split(';', qucs::SkipEmptyParts));
+
+            QRegularExpression ac_rx("^\\s*ac\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression sp_rx("^\\s*sp\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression noise_rx("^\\s*noise\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression disto_rx("^\\s*disto\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression fft_rx("^\\s*fft\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression four_rx("^\\s*(four|fourier)\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression dc_rx("^\\s*dc\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression op_rx("^\\s*op\\s*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression tran_rx("^\\s*tran\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression sens_ac_rx("^\\s*sens\\s.*ac\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression sens_dc_rx("^\\s*sens\\s.*", QRegularExpression::CaseInsensitiveOption);
+            QRegularExpression pz_rx("^\\s*pz\\s.*", QRegularExpression::CaseInsensitiveOption);
+
+            QStringList lines = pc->getSpiceNetlist().split('\n');
+            for ( const QString& line : lines ) {
+                if      ( ac_rx.match(line).hasMatch() )      freqSims++ ;
+                else if ( sp_rx.match(line).hasMatch() )      freqSims++ ;
+                else if ( noise_rx.match(line).hasMatch() )   freqSims++ ;
+                else if ( disto_rx.match(line).hasMatch() )   freqSims++ ;
+                else if ( fft_rx.match(line).hasMatch() )     freqSims++ ;
+                else if ( four_rx.match(line).hasMatch() )    fourSims++ ;
+                else if ( dc_rx.match(line).hasMatch() )      dcSims++ ;
+                else if ( op_rx.match(line).hasMatch() )      dcSims++ ;
+                else if ( tran_rx.match(line).hasMatch() )    timeSims++ ;
+                else if ( sens_ac_rx.match(line).hasMatch() ) freqSims++ ;
+                else if ( sens_dc_rx.match(line).hasMatch() ) dcSims++ ;
+                else if ( pz_rx.match(line).hasMatch() )      pzSims++ ;
+            }
         } else if ( sim_typ == ".DISTO" ) {
             freqSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
@@ -234,6 +267,7 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
             }
             nods = "inoise_spectrum onoise_spectrum";
         } else if ( sim_typ == ".PZ" ) {
+            pzSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
             QString out = "spice4qucs." + sim_name + ".cir.pz";
             // Add it twice for poles and zeros
@@ -260,27 +294,32 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
         } else if ( sim_typ == ".DC" ) {
             dcSims++;
             spiceNetlist.append(pc->getSpiceNetlist());
-            outputs.append("spice4qucs." + sim_name + ".ngspice.dc.print");
         } else if ( sim_typ == ".SW" ) {
             QString SwpSim = pc->Props.at(0)->Value.toLower();
             if ( SwpSim.startsWith("dc") ) {
-                dcswpSims++;
+                dcSims++;
                 spiceNetlist.append(pc->getSpiceNetlist());
             } else
                 continue;
         } else
             continue;
 
-        QStringList dep_vars;
-        for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
-            Component *pc1 = Sch->DocComps.at(i);
-            if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
-            if ( pc1->Model == "Eqn" || pc1->Model == "NutmegEq" )
-                spiceNetlist.append(pc1->getEquations(sim_name, dep_vars));
+        if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") ) {
+            QStringList dep_vars;
+            for ( unsigned int i = 0 ; i < Sch->DocComps.count() ; i++ ) {
+                Component *pc1 = Sch->DocComps.at(i);
+                if ( pc1->isActive != COMP_IS_ACTIVE ) continue;
+                if ( pc1->Model == "Eqn" || pc1->Model == "NutmegEq" )
+                    spiceNetlist.append(pc1->getEquations(sim_name, dep_vars));
+            }
+            nods.append(' ' + dep_vars.join(' '));
         }
-        nods.append(' ' + dep_vars.join(' '));
 
-        if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") && (sim_typ != ".DC") ) {
+        if ( sim_typ == ".DC" ) {
+            QString out = "spice4qucs." + sim_name + ".ngspice.dc.print";
+            spiceNetlist.append(QString("print %1 > %2\n").arg(nods).arg(out));
+            outputs.append(out);
+        } else if ( (sim_typ != ".PZ") && (sim_typ != ".SENS") && (sim_typ != ".SENS_AC") ) {
             nods = nods.simplified();
             if ( !nods.isEmpty() ) {
                 QString basenam = "spice4qucs";
@@ -322,7 +361,16 @@ void Ngspice::createNetlist(QTextStream &stream, int ,
            << ".endc\n";
     stream << ".END\n";
 
-    needsPrefix = ( (dcSims | dcswpSims | freqSims | timeSims | fourSims) > 1 );
+    needsPrefix = ( (dcSims | freqSims | timeSims | fourSims | pzSims) > 1 );
+
+    qDebug() << '\n'
+             << "Simulations:\n"
+             << "DC:        " << dcSims << '\n'
+             << "Frequency: " << freqSims << '\n'
+             << "Time:      " << timeSims << '\n'
+             << "Fourier:   " << fourSims << '\n'
+             << "Pole-Zero: " << pzSims << '\n'
+             << '\n';
 }
 
 /*!
@@ -352,7 +400,7 @@ QString Ngspice::getParentSWPscript(Component *pc_swp, QString sim, bool before,
             }
         }
     }
-    return QString("");
+    return QString();
 }
 
 /*!
@@ -378,12 +426,16 @@ void Ngspice::slotSimulate()
     }
 
     if (!checkGround()) {
-        output.append("No Ground found. Please add at least one ground!\n");
+        output.append("No Ground found. Please add at least one ground!\n"
+                      "Press Insert->Ground in the main menu and connect ground to one "
+                      "of the schematic nodes.\n");
         checker_error = true;
     }
 
     if (!checkSimulations()) {
-        output.append("No simulation found. Please add at least one simulation!\n");
+        output.append("No simulation found. Please add at least one simulation!\n"
+                      "Navigate to the \"simulations\" group in the components panel (left)"
+                      " and drag simulation to the schematic sheet. Then define its parameters.\n");
         checker_error = true;
     }
 
@@ -434,7 +486,7 @@ void Ngspice::slotSimulate()
     QString ngsp_cmd = cmd_args.at(0);
     cmd_args.removeAt(0);
     SimProcess->start(ngsp_cmd,cmd_args);
-    if (QucsMain)
+    if (QucsMain != nullptr)
     emit started();
 }
 
@@ -580,13 +632,29 @@ void Ngspice::cleanSpiceinit()
 
 void Ngspice::createSpiceinit(const QString &initial_spiceinit)
 {
-    if (initial_spiceinit.isEmpty()) return;
-    QFile spinit(spinit_name);
-    if (spinit.open(QIODevice::WriteOnly)) {
-        QTextStream stream(&spinit);
-        if (!initial_spiceinit.isEmpty()) {
-          stream << initial_spiceinit << '\n';
-        }
-        spinit.close();
-    }
+  auto compat_mode = _settings::Get().item<int>("NgspiceCompatMode");
+  QString compat_str;
+  switch(compat_mode) {
+  case spicecompat::NgspLTspice:
+    compat_str = "set ngbehavior=ltpsa\n";
+    break;
+  case spicecompat::NgspHSPICE:
+    compat_str = "set ngbehavior=hsa\n";
+    break;
+  case spicecompat::NgspS3:
+    compat_str = "set ngbehavior=s3\n";
+    break;
+  default: break;
+  }
+  if (initial_spiceinit.isEmpty() &&
+      compat_str.isEmpty()) {
+    return;
+  }
+  QFile spinit(spinit_name);
+  if (spinit.open(QIODevice::WriteOnly)) {
+    QTextStream stream(&spinit);
+    stream << compat_str << '\n';
+    stream << initial_spiceinit << '\n';
+    spinit.close();
+  }
 }
