@@ -42,21 +42,20 @@
 #include "node.h"
 #include "printerwriter.h"
 #include "imagewriter.h"
-
 #include "schematic.h"
+#include "settings.h"
 #include "module.h"
 #include "misc.h"
 
-#include "components/components.h"
 
 #include "extsimkernels/ngspice.h"
 #include "extsimkernels/xyce.h"
 
-#ifdef _WIN32
+#if defined(_WIN32) ||defined(__MINGW32__)
 #include <windows.h>  //for OutputDebugString
 #endif
 
-#ifdef __MINGW32__
+#if defined(_WIN32) ||defined(__MINGW32__)
 #define executableSuffix ".exe"
 #else
 #define executableSuffix ""
@@ -64,7 +63,7 @@
 
 tQucsSettings QucsSettings;
 
-QucsApp *QucsMain = 0;  // the Qucs application itself
+QucsApp *QucsMain = nullptr;  // the Qucs application itself
 QString lastDir;    // to remember last directory for several dialogs
 QStringList qucsPathList;
 VersionTriplet QucsVersion; // Qucs version string
@@ -75,131 +74,77 @@ bool loadSettings()
 {
     QSettings settings("qucs","qucs_s");
 
-    if(settings.contains("DefaultSimulator"))
-        QucsSettings.DefaultSimulator = settings.value("DefaultSimulator").toInt();
-    else QucsSettings.DefaultSimulator = spicecompat::simNotSpecified;
+    QucsSettings.DefaultSimulator = _settings::Get().item<int>("DefaultSimulator");
+    QucsSettings.firstRun = _settings::Get().item<bool>("firstRun");
 
-    if(settings.contains("firstRun"))
-        QucsSettings.firstRun = settings.value("firstRun").toBool();
-    else QucsSettings.firstRun = true;
+    /*** Temporarily continue to use QucsSettings to make sure all settings convert okay and remain compatible ***/
+    QucsSettings.font.fromString(_settings::Get().item<QString>("font"));
+    QucsSettings.appFont.fromString(_settings::Get().item<QString>("appFont"));
+    QucsSettings.textFont.fromString(_settings::Get().item<QString>("textFont"));
+    QucsSettings.largeFontSize = _settings::Get().item<double>("LargeFontSize");
+    QucsSettings.maxUndo = _settings::Get().item<int>("maxUndo");
+    QucsSettings.NodeWiring = _settings::Get().item<int>("NodeWiring");
+    QucsSettings.BGColor = _settings::Get().item<QString>("BGColor");
+    QucsSettings.Editor = _settings::Get().item<QString>("Editor");
+    QucsSettings.FileTypes = _settings::Get().item<QStringList>("FileTypes");
+    QucsSettings.Language = _settings::Get().item<QString>("Language");
 
-    if(settings.contains("x"))QucsSettings.x=settings.value("x").toInt();
-    if(settings.contains("y"))QucsSettings.y=settings.value("y").toInt();
-    if(settings.contains("dx"))QucsSettings.dx=settings.value("dx").toInt();
-    if(settings.contains("dy"))QucsSettings.dy=settings.value("dy").toInt();
-    if(settings.contains("font"))QucsSettings.font.fromString(settings.value("font").toString());
-    if(settings.contains("appFont"))QucsSettings.appFont.fromString(settings.value("appFont").toString());
-    if(settings.contains("textFont"))QucsSettings.textFont.fromString(settings.value("textFont").toString());
-    if(settings.contains("LargeFontSize"))QucsSettings.largeFontSize=settings.value("LargeFontSize").toDouble(); // use toDouble() as it can interpret the string according to the current locale
-    if(settings.contains("maxUndo"))QucsSettings.maxUndo=settings.value("maxUndo").toInt();
-    if(settings.contains("NodeWiring"))QucsSettings.NodeWiring=settings.value("NodeWiring").toInt();
-    if(settings.contains("BGColor"))QucsSettings.BGColor = misc::ColorFromString(settings.value("BGColor").toString());
-    if(settings.contains("Editor"))QucsSettings.Editor=settings.value("Editor").toString();
-    if(settings.contains("FileTypes"))QucsSettings.FileTypes=settings.value("FileTypes").toStringList();
-    if(settings.contains("Language"))QucsSettings.Language=settings.value("Language").toString();
-    if(settings.contains("Comment"))QucsSettings.Comment=misc::ColorFromString(settings.value("Comment").toString());
-    if(settings.contains("String"))QucsSettings.String=misc::ColorFromString(settings.value("String").toString());
-    if(settings.contains("Integer"))QucsSettings.Integer=misc::ColorFromString(settings.value("Integer").toString());
-    if(settings.contains("Real"))QucsSettings.Real=misc::ColorFromString(settings.value("Real").toString());
-    if(settings.contains("Character"))QucsSettings.Character=misc::ColorFromString(settings.value("Character").toString());
-    if(settings.contains("Type"))QucsSettings.Type=misc::ColorFromString(settings.value("Type").toString());
-    if(settings.contains("Attribute"))QucsSettings.Attribute=misc::ColorFromString(settings.value("Attribute").toString());
-    if(settings.contains("Directive"))QucsSettings.Directive=misc::ColorFromString(settings.value("Directive").toString());
-    if(settings.contains("Task"))QucsSettings.Task=misc::ColorFromString(settings.value("Task").toString());
-
-    if (settings.contains("panelIconsTheme")) QucsSettings.panelIconsTheme = settings.value("panelIconsTheme").toInt();
-    else QucsSettings.panelIconsTheme = qucs::autoIcons;
-    if (settings.contains("compIconsTheme")) QucsSettings.compIconsTheme = settings.value("compIconsTheme").toInt();
-    else QucsSettings.compIconsTheme = qucs::autoIcons;
+    // Editor syntax highlighting settings.
+    QucsSettings.Comment = _settings::Get().item<QString>("Comment");
+    QucsSettings.String = _settings::Get().item<QString>("String");
+    QucsSettings.Integer = _settings::Get().item<QString>("Integer");
+    QucsSettings.Real = _settings::Get().item<QString>("Real");
+    QucsSettings.Character = _settings::Get().item<QString>("Character");
+    QucsSettings.Type = _settings::Get().item<QString>("Type");
+    QucsSettings.Attribute = _settings::Get().item<QString>("Attribute");
+    QucsSettings.Directive = _settings::Get().item<QString>("Directive");
+    QucsSettings.Task = _settings::Get().item<QString>("Task");
 
+    // TODO: Convert this to the new settings model.
     if(settings.contains("Qucsator")) {
         QucsSettings.Qucsator = settings.value("Qucsator").toString();
         QFileInfo inf(QucsSettings.Qucsator);
         QucsSettings.QucsatorDir = inf.canonicalPath() + QDir::separator();
         if (QucsSettings.Qucsconv.isEmpty())
-            QucsSettings.Qucsconv = QucsSettings.QucsatorDir + QDir::separator() + "qucsconv" + executableSuffix;
+            QucsSettings.Qucsconv = QucsSettings.QucsatorDir + QDir::separator() + "qucsconv_rf" + executableSuffix;
     } else {
-        QucsSettings.Qucsator = QucsSettings.BinDir + "qucsator" + executableSuffix;
+        QucsSettings.Qucsator = QucsSettings.BinDir + "qucsator_rf" + executableSuffix;
         QucsSettings.QucsatorDir = QucsSettings.BinDir;
         if (QucsSettings.Qucsconv.isEmpty())
-            QucsSettings.Qucsconv = QucsSettings.BinDir + "qucsconv" + executableSuffix;
+            QucsSettings.Qucsconv = QucsSettings.BinDir + "qucsconv_rf" + executableSuffix;
     }
-    //if(settings.contains("BinDir"))QucsSettings.BinDir = settings.value("BinDir").toString();
-    //if(settings.contains("LangDir"))QucsSettings.LangDir = settings.value("LangDir").toString();
-    //if(settings.contains("LibDir"))QucsSettings.LibDir = settings.value("LibDir").toString();
-    if(settings.contains("AdmsXmlBinDir"))QucsSettings.AdmsXmlBinDir.setPath(settings.value("AdmsXmlBinDir").toString());
-    if(settings.contains("AscoBinDir"))QucsSettings.AscoBinDir.setPath(settings.value("AscoBinDir").toString());
-    //if(settings.contains("OctaveDir"))QucsSettings.OctaveDir = settings.value("OctaveDir").toString();
-    //if(settings.contains("ExamplesDir"))QucsSettings.ExamplesDir = settings.value("ExamplesDir").toString();
-    //if(settings.contains("DocDir"))QucsSettings.DocDir = settings.value("DocDir").toString();
-    if(settings.contains("NgspiceExecutable")) QucsSettings.NgspiceExecutable = settings.value("NgspiceExecutable").toString();
-    else {
-#ifdef Q_OS_WIN
-        QucsSettings.NgspiceExecutable = "ngspice_con.exe";
-#else
-        QucsSettings.NgspiceExecutable = "ngspice";
-#endif
-    }
-    if(settings.contains("XyceExecutable")) QucsSettings.XyceExecutable = settings.value("XyceExecutable").toString();
-    else {
-#ifdef Q_OS_WIN
-        QucsSettings.XyceExecutable = "Xyce.exe";
-#else
-        QucsSettings.XyceExecutable = "/usr/local/Xyce-Release-6.8.0-OPENSOURCE/bin/Xyce";
-#endif
-    }
-    if(settings.contains("XyceParExecutable")) QucsSettings.XyceParExecutable = settings.value("XyceParExecutable").toString();
-    else QucsSettings.XyceParExecutable = "mpirun -np %p /usr/local/Xyce-Release-6.8.0-OPENMPI-OPENSOURCE/bin/Xyce";
-    if(settings.contains("SpiceOpusExecutable")) QucsSettings.SpiceOpusExecutable = settings.value("SpiceOpusExecutable").toString();
-    else QucsSettings.SpiceOpusExecutable = "spiceopus";
-    if(settings.contains("Nprocs")) QucsSettings.NProcs = settings.value("Nprocs").toInt();
-    else QucsSettings.NProcs = 4;
-    if(settings.contains("S4Q_workdir")) QucsSettings.S4Qworkdir = settings.value("S4Q_workdir").toString();
-    else QucsSettings.S4Qworkdir = QDir::toNativeSeparators(QucsSettings.QucsWorkDir.absolutePath()+"/spice4qucs");
-    if(settings.contains("SimParameters")) QucsSettings.SimParameters = settings.value("SimParameters").toString();
-    else QucsSettings.SimParameters = "";
-    if(settings.contains("OctaveExecutable")) {
-        QucsSettings.OctaveExecutable = settings.value("OctaveExecutable").toString();
-    } else {
-        if(settings.contains("OctaveBinDir")) {
-            QucsSettings.OctaveExecutable = settings.value("OctaveBinDir").toString() +
-                    QDir::separator() + "octave" + QString(executableSuffix);
-        } else QucsSettings.OctaveExecutable = "octave" + QString(executableSuffix);
-    }
-    if(settings.contains("OpenVAFExecutable")) {
-        QucsSettings.OpenVAFExecutable = settings.value("OpenVAFExecutable").toString();
-    } else {
-        QucsSettings.OpenVAFExecutable = "openvaf" + QString(executableSuffix);
-    }
-    if(settings.contains("QucsHomeDir"))
-      if(settings.value("QucsHomeDir").toString() != "")
-         QucsSettings.QucsHomeDir.setPath(settings.value("QucsHomeDir").toString());
-    QucsSettings.QucsWorkDir = QucsSettings.QucsHomeDir;
 
-    if (settings.contains("IgnoreVersion")) QucsSettings.IgnoreFutureVersion = settings.value("IgnoreVersion").toBool();
-    // check also for old setting name with typo...
-    else if (settings.contains("IngnoreVersion")) QucsSettings.IgnoreFutureVersion = settings.value("IngnoreVersion").toBool();
-    else QucsSettings.IgnoreFutureVersion = false;
+    QucsSettings.AdmsXmlBinDir.setPath(_settings::Get().item<QString>("AdmsXmlBinDir"));
+    QucsSettings.AscoBinDir.setPath(_settings::Get().item<QString>("AscoBinDir"));
+    QucsSettings.NgspiceExecutable = _settings::Get().item<QString>("NgspiceExecutable");
+    QucsSettings.XyceExecutable = _settings::Get().item<QString>("XyceExecutable");
+    QucsSettings.XyceParExecutable = _settings::Get().item<QString>("XyceParExecutable");
+    QucsSettings.SpiceOpusExecutable = _settings::Get().item<QString>("SpiceOpusExecutable");
+    QucsSettings.NProcs = _settings::Get().item<int>("Nprocs");
+   
+    // TODO: Currently the default settings cannot include other settings during initialisation. This is a 
+    // problem for this setting as it needs to include the QucsWorkDir setting. Therefore, set the default to an
+    // empty string and populate it here by brute force.
+    QucsSettings.S4Qworkdir = _settings::Get().item<QString>("S4Q_workdir");
+    if (QucsSettings.S4Qworkdir == "")
+      QucsSettings.S4Qworkdir = QDir::toNativeSeparators(QucsSettings.QucsWorkDir.absolutePath()+"/spice4qucs");
 
-    if (settings.contains("GraphAntiAliasing")) QucsSettings.GraphAntiAliasing = settings.value("GraphAntiAliasing").toBool();
-    else QucsSettings.GraphAntiAliasing = false;
+    QucsSettings.SimParameters = _settings::Get().item<QString>("SimParameters");
+    QucsSettings.OctaveExecutable = _settings::Get().item<QString>("OctaveExecutable");
+    QucsSettings.OpenVAFExecutable = _settings::Get().item<QString>("OpenVAFExecutable");
 
-    if (settings.contains("TextAntiAliasing")) QucsSettings.TextAntiAliasing = settings.value("TextAntiAliasing").toBool();
-    else QucsSettings.TextAntiAliasing = false;
+    QucsSettings.RFLayoutExecutable = _settings::Get().item<QString>("RFLayoutExecutable");
 
-    if (settings.contains("fullTraceName")) QucsSettings.fullTraceName = settings.value("fullTraceName").toBool();
-    else QucsSettings.fullTraceName = false;
+    QucsSettings.qucsWorkspaceDir.setPath(_settings::Get().item<QString>("QucsHomeDir"));
+    QucsSettings.QucsWorkDir = QucsSettings.qucsWorkspaceDir;
+    QucsSettings.tempFilesDir.setPath(QStandardPaths::writableLocation(QStandardPaths::CacheLocation));
 
-    QucsSettings.FileToolbar = !settings.contains("FileToolbar") || settings.value("FileToolbar").toBool();
-    QucsSettings.EditToolbar = !settings.contains("EditToolbar") || settings.value("EditToolbar").toBool();
-    QucsSettings.ViewToolbar = !settings.contains("ViewToolbar") || settings.value("ViewToolbar").toBool();
-    QucsSettings.WorkToolbar = !settings.contains("WorkToolbar") || settings.value("WorkToolbar").toBool();
-    QucsSettings.SimulateToolbar = !settings.contains("SimulateToolbar") || settings.value("SimulateToolbar").toBool();
-
-    QucsSettings.RecentDocs = settings.value("RecentDocs").toString().split("*",qucs::SkipEmptyParts);
+    QucsSettings.IgnoreFutureVersion = _settings::Get().item<bool>("IgnoreVersion");
+    QucsSettings.GraphAntiAliasing = _settings::Get().item<bool>("GraphAntiAliasing");
+    QucsSettings.TextAntiAliasing = _settings::Get().item<bool>("TextAntiAliasing");
+    QucsSettings.fullTraceName = _settings::Get().item<bool>("fullTraceName");
+    QucsSettings.RecentDocs = _settings::Get().item<QString>("RecentDocs").split("*",qucs::SkipEmptyParts);
     QucsSettings.numRecentDocs = QucsSettings.RecentDocs.count();
-
-
     QucsSettings.spiceExtensions << "*.sp" << "*.cir" << "*.spc" << "*.spi";
 
     // If present read in the list of directory paths in which Qucs should
@@ -224,66 +169,54 @@ bool saveApplSettings()
 {
     QSettings settings ("qucs","qucs_s");
 
-    settings.setValue("DefaultSimulator", QucsSettings.DefaultSimulator);
-    settings.setValue("firstRun", false);
+    // Note: It is not really necessary to take the following reference, but it 
+    // arguably makes the code slightly cleaner - thoughts? To be clear:
+    // qs.item<int>() is identical to _settings::get().item<int>()
+    settingsManager& qs = _settings::Get();    
 
-    settings.setValue("x", QucsSettings.x);
-    settings.setValue("y", QucsSettings.y);
-    settings.setValue("dx", QucsSettings.dx);
-    settings.setValue("dy", QucsSettings.dy);
-    settings.setValue("font", QucsSettings.font.toString());
-    settings.setValue("appFont", QucsSettings.appFont.toString());
-    settings.setValue("textFont", QucsSettings.textFont.toString());
+    qs.setItem<int>("DefaultSimulator", QucsSettings.DefaultSimulator);
+    qs.setItem<bool>("firstRun", false);
+    qs.setItem<QString>("font", QucsSettings.font.toString());
+    qs.setItem<QString>("appFont", QucsSettings.appFont.toString());
+    qs.setItem<QString>("textFont", QucsSettings.textFont.toString());
+    if (QucsMain != nullptr) {
+      qs.setItem<QByteArray>("MainWindowGeometry", QucsMain->saveGeometry());
+    }
+    
     // store LargeFontSize as a string, so it will be also human-readable in the settings file (will be a @Variant() otherwise)
-    settings.setValue("LargeFontSize", QString::number(QucsSettings.largeFontSize));
-    settings.setValue("maxUndo", QucsSettings.maxUndo);
-    settings.setValue("NodeWiring", QucsSettings.NodeWiring);
-    settings.setValue("BGColor", QucsSettings.BGColor.name());
-    settings.setValue("Editor", QucsSettings.Editor);
-    settings.setValue("FileTypes", QucsSettings.FileTypes);
-    settings.setValue("Language", QucsSettings.Language);
-    settings.setValue("Comment", QucsSettings.Comment.name());
-    settings.setValue("String", QucsSettings.String.name());
-    settings.setValue("Integer", QucsSettings.Integer.name());
-    settings.setValue("Real", QucsSettings.Real.name());
-    settings.setValue("Character", QucsSettings.Character.name());
-    settings.setValue("Type", QucsSettings.Type.name());
-    settings.setValue("Attribute", QucsSettings.Attribute.name());
-    settings.setValue("Directive", QucsSettings.Directive.name());
-    settings.setValue("Task", QucsSettings.Task.name());
-    //settings.setValue("Qucsator", QucsSettings.Qucsator);
-    //settings.setValue("BinDir", QucsSettings.BinDir);
-    //settings.setValue("LangDir", QucsSettings.LangDir);
-    //settings.setValue("LibDir", QucsSettings.LibDir);
-    settings.setValue("AdmsXmlBinDir", QucsSettings.AdmsXmlBinDir.canonicalPath());
-    settings.setValue("AscoBinDir", QucsSettings.AscoBinDir.canonicalPath());
-    //settings.setValue("OctaveDir", QucsSettings.OctaveDir);
-    //settings.setValue("ExamplesDir", QucsSettings.ExamplesDir);
-    //settings.setValue("DocDir", QucsSettings.DocDir);
-    //settings.setValue("OctaveBinDir", QucsSettings.OctaveBinDir.canonicalPath());
-    settings.setValue("NgspiceExecutable",QucsSettings.NgspiceExecutable);
-    settings.setValue("XyceExecutable",QucsSettings.XyceExecutable);
-    settings.setValue("XyceParExecutable",QucsSettings.XyceParExecutable);
-    settings.setValue("SpiceOpusExecutable",QucsSettings.SpiceOpusExecutable);
-    settings.setValue("Qucsator",QucsSettings.Qucsator);
-    settings.setValue("Nprocs",QucsSettings.NProcs);
-    settings.setValue("S4Q_workdir",QucsSettings.S4Qworkdir);
-    settings.setValue("SimParameters",QucsSettings.SimParameters);
-    // settings.setValue("OctaveBinDir", QucsSettings.OctaveBinDir.canonicalPath());
-    settings.setValue("OctaveExecutable",QucsSettings.OctaveExecutable);
-    settings.setValue("OpenVAFExecutable",QucsSettings.OpenVAFExecutable);
-    settings.setValue("QucsHomeDir", QucsSettings.QucsHomeDir.canonicalPath());
-    settings.setValue("IgnoreVersion", QucsSettings.IgnoreFutureVersion);
-    settings.setValue("GraphAntiAliasing", QucsSettings.GraphAntiAliasing);
-    settings.setValue("TextAntiAliasing", QucsSettings.TextAntiAliasing);
-    settings.setValue("fullTraceName",QucsSettings.fullTraceName);
-    settings.setValue("panelIconsTheme",QucsSettings.panelIconsTheme);
-    settings.setValue("compIconsTheme",QucsSettings.compIconsTheme);
-    settings.setValue("FileToolbar", QucsSettings.FileToolbar);
-    settings.setValue("EditToolbar", QucsSettings.EditToolbar);
-    settings.setValue("ViewToolbar", QucsSettings.ViewToolbar);
-    settings.setValue("WorkToolbar", QucsSettings.WorkToolbar);
-    settings.setValue("SimulateToolbar", QucsSettings.SimulateToolbar);
+    qs.setItem<QString>("LargeFontSize", QString::number(QucsSettings.largeFontSize));
+    qs.setItem<unsigned int>("maxUndo", QucsSettings.maxUndo);
+    qs.setItem<unsigned int>("NodeWiring", QucsSettings.NodeWiring);
+    qs.setItem<QString>("BGColor", QucsSettings.BGColor.name());
+    qs.setItem<QString>("Editor", QucsSettings.Editor);
+    qs.setItem<QStringList>("FileTypes", QucsSettings.FileTypes);
+    qs.setItem<QString>("Language", QucsSettings.Language);
+    qs.setItem<QString>("Comment", QucsSettings.Comment.name());
+    qs.setItem<QString>("String", QucsSettings.String.name());
+    qs.setItem<QString>("Integer", QucsSettings.Integer.name());
+    qs.setItem<QString>("Real", QucsSettings.Real.name());
+    qs.setItem<QString>("Character", QucsSettings.Character.name());
+    qs.setItem<QString>("Type", QucsSettings.Type.name());
+    qs.setItem<QString>("Attribute", QucsSettings.Attribute.name());
+    qs.setItem<QString>("Directive", QucsSettings.Directive.name());
+    qs.setItem<QString>("Task", QucsSettings.Task.name());
+    qs.setItem<QString>("AdmsXmlBinDir", QucsSettings.AdmsXmlBinDir.canonicalPath());
+    qs.setItem<QString>("AscoBinDir", QucsSettings.AscoBinDir.canonicalPath());    
+    qs.setItem<QString>("NgspiceExecutable",QucsSettings.NgspiceExecutable);
+    qs.setItem<QString>("XyceExecutable",QucsSettings.XyceExecutable);
+    qs.setItem<QString>("XyceParExecutable",QucsSettings.XyceParExecutable);
+    qs.setItem<QString>("SpiceOpusExecutable",QucsSettings.SpiceOpusExecutable);
+    qs.setItem<QString>("Qucsator",QucsSettings.Qucsator);
+    qs.setItem<int>("Nprocs",QucsSettings.NProcs);
+    qs.setItem<QString>("S4Q_workdir",QucsSettings.S4Qworkdir);
+    qs.setItem<QString>("SimParameters",QucsSettings.SimParameters);    
+    qs.setItem<QString>("OctaveExecutable",QucsSettings.OctaveExecutable);
+    qs.setItem<QString>("OpenVAFExecutable",QucsSettings.OpenVAFExecutable);
+    qs.setItem<QString>("QucsHomeDir", QucsSettings.qucsWorkspaceDir.canonicalPath());
+    qs.setItem<bool>("IgnoreVersion", QucsSettings.IgnoreFutureVersion);
+    qs.setItem<bool>("GraphAntiAliasing", QucsSettings.GraphAntiAliasing);
+    qs.setItem<bool>("TextAntiAliasing", QucsSettings.TextAntiAliasing);
+    qs.setItem<bool>("fullTraceName",QucsSettings.fullTraceName);
 
     // Copy the list of directory paths in which Qucs should
     // search for subcircuit schematics from qucsPathList
@@ -298,7 +231,6 @@ bool saveApplSettings()
      settings.endArray();
 
   return true;
-
 }
 
 /*!
@@ -369,6 +301,7 @@ Schematic *openSchematic(QString schematic)
 int doNetlist(QString schematic, QString netlist)
 {
   QucsSettings.DefaultSimulator = spicecompat::simQucsator;
+  Module::registerModules();
   Schematic *sch = openSchematic(schematic);
   if (sch == NULL) {
     return 1;
@@ -427,6 +360,7 @@ int doNetlist(QString schematic, QString netlist)
 int runNgspice(QString schematic, QString dataset)
 {
     QucsSettings.DefaultSimulator = spicecompat::simNgspice;
+    Module::registerModules();
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -450,6 +384,7 @@ int runNgspice(QString schematic, QString dataset)
 int runXyce(QString schematic, QString dataset)
 {
     QucsSettings.DefaultSimulator = spicecompat::simXyce;
+    Module::registerModules();
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -473,6 +408,7 @@ int runXyce(QString schematic, QString dataset)
 int doNgspiceNetlist(QString schematic, QString netlist)
 {
     QucsSettings.DefaultSimulator = spicecompat::simNgspice;
+    Module::registerModules();
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -488,6 +424,7 @@ int doNgspiceNetlist(QString schematic, QString netlist)
 int doXyceNetlist(QString schematic, QString netlist)
 {
     QucsSettings.DefaultSimulator = spicecompat::simXyce;
+    Module::registerModules();
     Schematic *sch = openSchematic(schematic);
     if (sch == NULL) {
       return 1;
@@ -564,8 +501,8 @@ void createIcons() {
 
         QList<qucs::Line *> Lines      = c->Lines;
         QList<struct qucs::Arc *> Arcs = c-> Arcs;
-        QList<qucs::Area *> Rects      = c-> Rects;
-        QList<qucs::Area *> Ellips     = c-> Ellips;
+        QList<qucs::Rect *> Rects      = c-> Rects;
+        QList<qucs::Ellips *> Ellips     = c-> Ellipses;
         QList<Port *> Ports      = c->Ports;
         QList<Text*> Texts       = c->Texts;
 
@@ -584,11 +521,11 @@ void createIcons() {
           scene->addPath(*path);
         }
 
-        for(qucs::Area *a: Rects) {
+        for(qucs::Rect *a: Rects) {
           scene->addRect(a->x, a->y, a->w, a->h, a->Pen, a->Brush);
         }
 
-        for(qucs::Area *a: Ellips) {
+        for(qucs::Ellips *a: Ellips) {
           scene->addEllipse(a->x, a->y, a->w, a->h, a->Pen, a->Brush);
         }
 
@@ -837,23 +774,17 @@ int main(int argc, char *argv[])
   QucsSettings.appFont = QApplication::font();
   QucsSettings.textFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
   QucsSettings.font.setPointSize(12);
-  QSize size = QGuiApplication::primaryScreen()->size();
-  int w = size.width();
-  int h = size.height();
-  QucsSettings.x = w/8;
-  QucsSettings.y = h/8;
-  QucsSettings.dx = w*3/4;
-  QucsSettings.dy = h*3/4;
 
   // default
-  QString QucsWorkdirPath = QDir::homePath()+QDir::toNativeSeparators ("/.qucs");
-  QDir().mkpath(QucsWorkdirPath);
-  QucsSettings.QucsHomeDir.setPath(QucsWorkdirPath);
-  QucsSettings.QucsWorkDir.setPath(QucsSettings.QucsHomeDir.canonicalPath());
+  QString QucsWorkdirPath = QDir::homePath()+QDir::toNativeSeparators ("/QucsWorkspace");
+  QucsSettings.qucsWorkspaceDir.setPath(QucsWorkdirPath);
+  QucsSettings.QucsWorkDir.setPath(QucsSettings.qucsWorkspaceDir.canonicalPath());
 
   // load existing settings (if any)
   loadSettings();
 
+  QDir().mkpath(QucsSettings.qucsWorkspaceDir.absolutePath());
+  QDir().mkpath(QucsSettings.tempFilesDir.absolutePath());
 
   // continue to set up overrides or default settings (some are saved on exit)
 
@@ -899,7 +830,7 @@ int main(int argc, char *argv[])
   else {
       // default admsXml bindir same as Qucs
       QString admsExec;
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
       admsExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"admsXml.exe");
 #else
       admsExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"admsXml");
@@ -916,7 +847,7 @@ int main(int argc, char *argv[])
   else  {
       // default ASCO bindir same as Qucs
       QString ascoExec;
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
       ascoExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"asco.exe");
 #else
       ascoExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"asco");
