@@ -31,6 +31,7 @@
 #include "dialogs/textboxdialog.h"
 #include "dialogs/tuner.h"
 #include "extsimkernels/customsimdialog.h"
+#include "extsimkernels/spicelibcompdialog.h"
 #include "main.h"
 #include "module.h"
 #include "node.h"
@@ -53,14 +54,6 @@
 #include <climits>
 #include <cstdlib>
 
-#define DOC_X_POS(x) (int(float(x) / Doc->Scale) + Doc->ViewX1)
-#define DOC_Y_POS(y) (int(float(y) / Doc->Scale) + Doc->ViewY1)
-#define DOC_X_FPOS (float(Event->pos().x()) / Doc->Scale + float(Doc->ViewX1))
-#define DOC_Y_FPOS (float(Event->pos().y()) / Doc->Scale + float(Doc->ViewY1))
-
-#define SCR_X_POS(x) int(float(x - Doc->ViewX1) * Doc->Scale)
-#define SCR_Y_POS(y) int(float(y - Doc->ViewY1) * Doc->Scale)
-
 #define MIN_SELECT_SIZE 5.0
 
 QAction *formerAction; // remember action before drag n'drop etc.
@@ -68,7 +61,9 @@ QAction *formerAction; // remember action before drag n'drop etc.
 MouseActions::MouseActions(QucsApp *App_)
 {
     App = App_;          // pointer to main app
-    selElem = nullptr;         // no component/diagram is selected
+    if(selElem != nullptr){
+      selElem = nullptr;         // no component/diagram is selected
+    }
     isMoveEqual = false; // mouse cursor move x and y the same way
     focusElement = 0;    //element being interacted with mouse
 
@@ -76,7 +71,8 @@ MouseActions::MouseActions(QucsApp *App_)
     // initialize menu appearing by right mouse button click on component
     ComponentMenu = new QMenu(QucsMain);
     focusMEvent = new QMouseEvent(QEvent::MouseButtonPress,
-                                  QPoint(0, 0),
+                                  QPointF(0, 0),
+                                  QPointF(0, 0),
                                   Qt::NoButton,
                                   Qt::NoButton,
                                   Qt::NoModifier);
@@ -96,7 +92,6 @@ void MouseActions::setPainter(Schematic *Doc)
     Doc->PostPaintEvent(_Translate, -Doc->contentsX(), -Doc->contentsY());
     Doc->PostPaintEvent(_Scale, Doc->Scale, Doc->Scale);
     Doc->PostPaintEvent(_Translate, -Doc->ViewX1, -Doc->ViewY1);
-    Doc->PostPaintEvent(_DotLine);
     Doc->PostPaintEvent(_NotRop);
 }
 
@@ -184,9 +179,8 @@ void MouseActions::editLabel(Schematic *Doc, WireLabel *pl)
             pl->x1 -= pl->x2 - old_x2; // don't change position due to text width
     }
 
-    Doc->sizeOfAll(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
+    Doc->updateAllBoundingRect();
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -240,12 +234,13 @@ void MouseActions::endElementMoving(Schematic *Doc,
   if ((MAx3 != 0) || (MAy3 != 0)) // moved or put at the same place ?
     Doc->setChanged(true, true);
 
-  // enlarge viewarea if components lie outside the view
-  Doc->sizeOfAll(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
-  Doc->enlargeView(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
+  // Position of some elements of schematic has changed. This change
+  // is "external" to schematic and its state must be updated to
+  // take the changes into account
+  auto totalBounds = Doc->allBoundingRect();
+  Doc->enlargeView(totalBounds.left(), totalBounds.top(), totalBounds.right(), totalBounds.bottom());
 
   Doc->viewport()->update();
-  drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -312,10 +307,13 @@ void MouseActions::MMoveElement(Schematic *Doc, QMouseEvent *Event)
 
     //  qDebug() << "MMoveElement got selElem";
 
-    int x = Event->pos().x();
-    int y = Event->pos().y();
-    int fx = DOC_X_POS(x);
-    int fy = DOC_Y_POS(y);
+    QPoint contentsCoordinates = Event->pos();
+    QPoint modelCoordinates = Doc->contentsToModel(contentsCoordinates);
+
+    int x = contentsCoordinates.x();
+    int y = contentsCoordinates.y();
+    int fx = modelCoordinates.x();
+    int fy = modelCoordinates.y();
     int gx = fx;
     int gy = fy;
     Doc->setOnGrid(gx, gy);
@@ -325,17 +323,11 @@ void MouseActions::MMoveElement(Schematic *Doc, QMouseEvent *Event)
 
     if (selElem->Type == isPainting) {
         Doc->PostPaintEvent(_NotRop, 0, 0, 0, 0);
-        ((Painting *) selElem)->MouseMoving(Doc, x, y, gx, gy, Doc, fx, fy, drawn);
-        drawn = true;
+        ((Painting *) selElem)->MouseMoving(Doc, x, y, gx, gy, Doc, fx, fy);
         Doc->viewport()->update();
         return;
     } // of "if(isPainting)"
 
-    // ********** it is a component or diagram
-    if (drawn)
-        selElem->paintScheme(Doc); // erase old scheme
-    drawn = true;
-
     //  Component *comp = (Component*)selElem;
     //qDebug() << "desc" << comp->Description << "gx" << gx << "gy" << gy;
 
@@ -345,28 +337,53 @@ void MouseActions::MMoveElement(Schematic *Doc, QMouseEvent *Event)
 }
 
 /**
- * @brief draws wire aiming cross on Document view
+ * @brief draws wire aiming cross
  * @param Doc - pointer to Schematics object
- * @param fx  - document x-coordinate of center
- * @param fy  - document x-coordinate of center
+ * @param aimX  - model x-coordinate of aim
+ * @param aimY  - model y-coordinate of aim
  */
-static void paintAim(Schematic *Doc, int fx, int fy)
-{
-    //let we reserve couple of points at the edges of lines for some aesthetics,
-    //and visual check that our calculations has fit the widget window.
-    const int ldelta = 2;
+static void paintAim(Schematic *Doc, int aimX, int aimY) {
+    // What we want to do here is to draw a cross centered at (aimX, aimY)
+    // which lines don't touch the bounds of visible part of schematic,
+    // i.e. there should be a little gap between the line ends and picture
+    // bounds:
+    //
+    //       Bad                Good
+    // +---------+---+    +--------------+
+    // |         |   |    |         |    |
+    // +---------+---+    | --------+--- |
+    // |         |   |    |         |    |
+    // |         |   |    |         |    |
+    // +---------+---+    +--------------+
+    //
+    // The cross is drawn using Schematic 'PostPaintEvent' subsystem.
+    // This is not a requirement, it's just an inherited implementation.
+    // Maybe there is a better way to do it, but until it's found let's
+    // stick to the way things already work.
+    //
+    // PostPaintEvent subsystem operates in *model* coordinates – the coordinates
+    // used to locate components, wires, etc.
+    //
+    // To draw the cross we want we have to follow these steps:
+    //   1. Find the size of viewport (visible part of schematic)
+    //   2. Shrink it a bit. The resulting rectangle is the *bounding* for the cross
+    //   3. Transform bounding rectangle coordinates to model coordinate system.
+    //   4. Using resulting 'in-model' coordinates of bounding rectangle, post
+    //      two 'paint line' events
 
-    //left and upper edges of our lines
-    int lx0 = DOC_X_POS(Doc->contentsX() + ldelta);
-    int ly0 = DOC_Y_POS(Doc->contentsY() + ldelta);
+    const QRect viewportAimBounds =
+        QRect{0, 0, Doc->viewport()->width(), Doc->viewport()->height()}
+        .marginsRemoved(QMargins{2, 2, 2, 2});
 
-    //right and bottom edges
-    int lx1 = DOC_X_POS(Doc->contentsX() + Doc->viewport()->width() - 1 - ldelta);
-    int ly1 = DOC_Y_POS(Doc->contentsY() + Doc->viewport()->height() - 1 - ldelta);
+    const QRect aimBounds{
+        Doc->viewportToModel(viewportAimBounds.topLeft()),
+        Doc->viewportToModel(viewportAimBounds.bottomRight())
+    };
 
-    //post line paint events
-    Doc->PostPaintEvent(_Line, lx0, fy, lx1, fy);
-    Doc->PostPaintEvent(_Line, fx, ly0, fx, ly1);
+    // Horizontal line of cross
+    Doc->PostPaintEvent(_Line, aimBounds.left(), aimY, aimBounds.right(), aimY);
+    // Vertical line of cross
+    Doc->PostPaintEvent(_Line, aimX, aimBounds.top(), aimX, aimBounds.bottom());
 }
 
 //paint ghost line - horizontal
@@ -391,8 +408,9 @@ static void paintGhostLineV(Schematic *Doc, int fx, int fy, int fyy)
  */
 void MouseActions::MMoveWire2(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx2 = DOC_X_POS(Event->pos().x());
-    MAy2 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx2 = inModel.x();
+    MAy2 = inModel.y();
     Doc->setOnGrid(MAx2, MAy2);
     paintAim(Doc, MAx2, MAy2); //let we paint aim cross
 
@@ -418,12 +436,20 @@ void MouseActions::MMoveWire2(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveWire1(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
     Doc->setOnGrid(MAx3, MAy3);
     paintAim(Doc, MAx3, MAy3);
-    MAx2 = DOC_X_POS(Doc->contentsX() + Doc->viewport()->width() - 1 - 2);
-    MAx2 = DOC_Y_POS(Doc->contentsY() + Doc->viewport()->height() - 1 - 2);
+
+    inModel = Doc->contentsToModel(
+        QPoint{
+            Doc->contentsX() + Doc->viewport()->width() - 1 - 2,
+            Doc->contentsY() + Doc->viewport()->height() - 1 - 2
+        }
+    );
+    MAx2 = inModel.x();
+    MAx2 = inModel.y();
     Doc->viewport()->update();
 }
 
@@ -435,8 +461,9 @@ void MouseActions::MMoveWire1(Schematic *Doc, QMouseEvent *Event)
 void MouseActions::MMoveSelect(Schematic *Doc, QMouseEvent *Event)
 {
     //qDebug() << "MMoveSelect " << "select area";
-    MAx2 = DOC_X_POS(Event->pos().x()) - MAx1;
-    MAy2 = DOC_Y_POS(Event->pos().y()) - MAy1;
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx2 = inModel.x() - MAx1;
+    MAy2 = inModel.y() - MAy1;
     if (isMoveEqual) { // x and y size must be equal ?
         if (abs(MAx2) > abs(MAy2)) {
             if (MAx2 < 0)
@@ -459,8 +486,9 @@ void MouseActions::MMoveResizePainting(Schematic *Doc, QMouseEvent *Event)
 {
     setPainter(Doc);
 
-    MAx1 = DOC_X_POS(Event->pos().x());
-    MAy1 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx1 = inModel.x();
+    MAy1 = inModel.y();
     Doc->setOnGrid(MAx1, MAy1);
     ((Painting *) focusElement)->MouseResizeMoving(MAx1, MAy1, Doc);
 }
@@ -471,8 +499,9 @@ void MouseActions::MMoveMoving(Schematic *Doc, QMouseEvent *Event)
 {
     setPainter(Doc);
 
-    MAx2 = DOC_X_POS(Event->pos().x());
-    MAy2 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx2 = inModel.x();
+    MAy2 = inModel.y();
 
     Doc->setOnGrid(MAx2, MAy2);
     MAx3 = MAx1 = MAx2 - MAx1;
@@ -527,11 +556,13 @@ void MouseActions::MMoveMoving(Schematic *Doc, QMouseEvent *Event)
         pe->paintScheme(Doc);
     }
 
-    drawn = true;
     MAx1 = MAx2;
     MAy1 = MAy2;
     QucsMain->MouseMoveAction = &MouseActions::MMoveMoving2;
     QucsMain->MouseReleaseAction = &MouseActions::MReleaseMoving;
+    QucsMain->editRotate->blockSignals(true);
+    QucsMain->insLabel->blockSignals(true);
+    QucsMain->setMarker->blockSignals(true);
 }
 
 // -----------------------------------------------------------
@@ -540,15 +571,12 @@ void MouseActions::MMoveMoving2(Schematic *Doc, QMouseEvent *Event)
 {
   setPainter(Doc);
 
-  MAx2 = DOC_X_POS(Event->pos().x());
-  MAy2 = DOC_Y_POS(Event->pos().y());
+  auto inModel = Doc->contentsToModel(Event->pos());
+  MAx2 = inModel.x();
+  MAy2 = inModel.y();
 
   Element *pe;
-  if (drawn) // erase old scheme
-    for (pe = movingElements.first(); pe != nullptr; pe = movingElements.next())
-      pe->paintScheme(Doc);
 
-  drawn = true;
   if ((Event->modifiers().testFlag(Qt::ControlModifier)) == 0)
     Doc->setOnGrid(MAx2, MAy2); // use grid only if CTRL key not pressed
   MAx1 = MAx2 - MAx1;
@@ -576,12 +604,12 @@ void MouseActions::MMoveMoving2(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMovePaste(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx1 = DOC_X_POS(Event->pos().x());
-    MAy1 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx1 = inModel.x();
+    MAy1 = inModel.y();
     moveElements(Doc, MAx1, MAy1);
     paintElementsScheme(Doc);
 
-    drawn = true;
     QucsMain->MouseMoveAction = &MouseActions::MMoveMoving2;
     QucsMain->MouseReleaseAction = &MouseActions::MReleasePaste;
 }
@@ -591,8 +619,9 @@ void MouseActions::MMovePaste(Schematic *Doc, QMouseEvent *Event)
 void MouseActions::MMoveScrollBar(Schematic *Doc, QMouseEvent *Event)
 {
     TabDiagram *d = (TabDiagram *) focusElement;
-    int x = DOC_X_POS(Event->pos().x());
-    int y = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    int x = inModel.x();
+    int y = inModel.y();
 
     if (d->scrollTo(MAx2, x - MAx1, y - MAy1)) {
         Doc->setChanged(true, true, 'm'); // 'm' = only the first time
@@ -615,8 +644,9 @@ void MouseActions::MMoveScrollBar(Schematic *Doc, QMouseEvent *Event)
 */
 void MouseActions::MMoveDelete(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     // cannot draw on the viewport, it is displaced by the size of dock and toolbar
     Doc->PostPaintEvent(_Line, MAx3 - 15, MAy3 - 15, MAx3 + 15, MAy3 + 15, 0, 0, false);
@@ -630,8 +660,9 @@ void MouseActions::MMoveDelete(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveLabel(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     // paint marker
     Doc->PostPaintEvent(_Line, MAx3, MAy3, MAx3 + 10, MAy3 - 10);
@@ -651,8 +682,9 @@ void MouseActions::MMoveLabel(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveMarker(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3, MAy3 - 2, MAx3 - 8, MAy3 - 10);
     Doc->PostPaintEvent(_Line, MAx3 + 1, MAy3 - 3, MAx3 + 8, MAy3 - 10);
@@ -667,9 +699,10 @@ void MouseActions::MMoveMarker(Schematic *Doc, QMouseEvent *Event)
 void MouseActions::MMoveSetLimits(Schematic *Doc, QMouseEvent *Event)
 {
     // TODO: Refactor to a QRectF for easy normalisation etc.
-    // Update the second point of the selection rectangle. 
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    // Update the second point of the selection rectangle.
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 }
 
 /**
@@ -679,8 +712,9 @@ void MouseActions::MMoveSetLimits(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveMirrorY(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 - 11, MAy3 - 4, MAx3 - 9, MAy3 - 9);
     Doc->PostPaintEvent(_Line, MAx3 - 11, MAy3 - 3, MAx3 - 6, MAy3 - 3);
@@ -696,8 +730,9 @@ void MouseActions::MMoveMirrorY(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveMirrorX(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 - 4, MAy3 - 11, MAx3 - 9, MAy3 - 9);
     Doc->PostPaintEvent(_Line, MAx3 - 3, MAy3 - 11, MAx3 - 3, MAy3 - 6);
@@ -713,8 +748,9 @@ void MouseActions::MMoveMirrorX(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveRotate(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 - 6, MAy3 + 8, MAx3 - 6, MAy3 + 1);
     Doc->PostPaintEvent(_Line, MAx3 - 7, MAy3 + 8, MAx3 - 12, MAy3 + 8);
@@ -728,8 +764,9 @@ void MouseActions::MMoveRotate(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveActivate(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Rect, MAx3, MAy3 - 9, 14, 10);
     Doc->PostPaintEvent(_Line, MAx3, MAy3 - 9, MAx3 + 13, MAy3);
@@ -743,8 +780,9 @@ void MouseActions::MMoveActivate(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveOnGrid(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 + 10, MAy3 + 3, MAx3 + 25, MAy3 + 3);
     Doc->PostPaintEvent(_Line, MAx3 + 10, MAy3 + 7, MAx3 + 25, MAy3 + 7);
@@ -761,8 +799,9 @@ void MouseActions::MMoveOnGrid(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveMoveTextB(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 + 14, MAy3, MAx3 + 16, MAy3);
     Doc->PostPaintEvent(_Line, MAx3 + 23, MAy3, MAx3 + 25, MAy3);
@@ -781,8 +820,9 @@ void MouseActions::MMoveMoveTextB(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveMoveText(Schematic *Doc, QMouseEvent *Event)
 {
-    int newX = DOC_X_POS(Event->pos().x());
-    int newY = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    int newX = inModel.x();
+    int newY = inModel.y();
     MAx1 += newX - MAx3;
     MAy1 += newY - MAy3;
     MAx3 = newX;
@@ -798,8 +838,9 @@ void MouseActions::MMoveMoveText(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MMoveZoomIn(Schematic *Doc, QMouseEvent *Event)
 {
-    MAx3 = DOC_X_POS(Event->pos().x());
-    MAy3 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx3 = inModel.x();
+    MAy3 = inModel.y();
 
     Doc->PostPaintEvent(_Line, MAx3 + 14, MAy3, MAx3 + 22, MAy3);
     Doc->PostPaintEvent(_Line, MAx3 + 18, MAy3 - 4, MAx3 + 18, MAy3 + 4);
@@ -956,7 +997,6 @@ void MouseActions::rightPressMenu(Schematic *Doc, QMouseEvent *Event, float fX,
     ComponentMenu->popup(Event->globalPos());
 #endif
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1028,9 +1068,8 @@ void MouseActions::MPressLabel(Schematic *Doc, QMouseEvent *, float fX, float fY
             pn->setName(Name, Value, xl, yl);
     }
 
-    Doc->sizeOfAll(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
+    Doc->updateAllBoundingRect();
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1128,7 +1167,6 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, float fX, fl
             // Update matching wire label highlighting
             Doc->highlightWireLabels();
             Doc->viewport()->update();
-            drawn = false;
             return;
 
         case isComponentText: // property text of component ?
@@ -1170,7 +1208,6 @@ void MouseActions::MPressSelect(Schematic *Doc, QMouseEvent *Event, float fX, fl
     QucsMain->MouseDoubleClickAction = 0;
     Doc->grabKeyboard(); // no keyboard inputs during move actions
     Doc->viewport()->update();
-    drawn = false;
 
     if (focusElement == 0) {
         MAx2 = 0; // if not clicking on an element => open a rectangle
@@ -1199,9 +1236,8 @@ void MouseActions::MPressDelete(Schematic *Doc, QMouseEvent *, float fX, float f
         pe->isSelected = true;
         Doc->deleteElements();
 
-        Doc->sizeOfAll(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
+        Doc->updateAllBoundingRect();
         Doc->viewport()->update();
-        drawn = false;
     }
 }
 
@@ -1219,7 +1255,6 @@ void MouseActions::MPressActivate(Schematic *Doc, QMouseEvent *, float fX, float
         QucsMain->MouseMoveAction = &MouseActions::MMoveSelect;
     }
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1240,7 +1275,6 @@ void MouseActions::MPressMirrorX(Schematic *Doc, QMouseEvent *, float fX, float
     }
 
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1262,7 +1296,6 @@ void MouseActions::MPressMirrorY(Schematic *Doc, QMouseEvent *, float fX, float
     }
 
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1286,7 +1319,7 @@ void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent *, float fX, float f
         ((Component *) e)->rotate();
         Doc->setCompPorts((Component *) e);
         // enlarge viewarea if component lies outside the view
-        ((Component *) e)->entireBounds(x1, y1, x2, y2, Doc->textCorr());
+        ((Component *) e)->entireBounds(x1, y1, x2, y2);
         Doc->enlargeView(x1, y1, x2, y2);
         break;
 
@@ -1318,7 +1351,6 @@ void MouseActions::MPressRotate(Schematic *Doc, QMouseEvent *, float fX, float f
         return;
     }
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1353,11 +1385,10 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, floa
             //    qDebug() << "  +-+ got to insert:" << Comp->Name;
 
             // enlarge viewarea if component lies outside the view
-            Comp->entireBounds(x1, y1, x2, y2, Doc->textCorr());
+            Comp->entireBounds(x1, y1, x2, y2);
             Doc->enlargeView(x1, y1, x2, y2);
             //Doc->setOnGrid(Comp->cx,Comp->cy);
 
-            drawn = false;
             Doc->viewport()->update();
             Doc->setChanged(true, true);
             rot = Comp->rotated;
@@ -1406,7 +1437,6 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, floa
         DiagramDialog *dia = new DiagramDialog(Diag, Doc);
         if (dia->exec() == QDialog::Rejected) { // don't insert if dialog canceled
             Doc->viewport()->update();
-            drawn = false;
             return;
         }
 
@@ -1432,7 +1462,6 @@ void MouseActions::MPressElement(Schematic *Doc, QMouseEvent *Event, float, floa
         Doc->setChanged(true, true);
 
         MMoveElement(Doc, Event); // needed before next mouse pressing
-        drawn = false;
     }
 }
 
@@ -1515,7 +1544,6 @@ void MouseActions::MPressWire2(Schematic *Doc, QMouseEvent *Event, float fX, flo
         //ALYS: excessive update. end of function does it.
         //Doc->viewport()->update();
 
-        drawn = false;
         if (set1 | set2)
             Doc->setChanged(true, true);
         MAx3 = MAx2;
@@ -1575,7 +1603,6 @@ void MouseActions::MPressMarker(Schematic *Doc, QMouseEvent *, float fX, float f
         Doc->enlargeView(x0 + pm->x1, y0 - pm->y1 - pm->y2, x0 + pm->x1 + pm->x2, y0 - pm->y1);
     }
     Doc->viewport()->update();
-    drawn = false;
 }
 
 /**
@@ -1613,7 +1640,6 @@ void MouseActions::MPressSetLimits(Schematic *Doc, QMouseEvent*, float fX, float
     }
 
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1627,11 +1653,10 @@ void MouseActions::MPressOnGrid(Schematic *Doc, QMouseEvent *, float fX, float f
         pe->isSelected = true;
         Doc->elementsOnGrid();
 
-        Doc->sizeOfAll(Doc->UsedX1, Doc->UsedY1, Doc->UsedX2, Doc->UsedY2);
+        Doc->updateAllBoundingRect();
         // Update matching wire label highlighting
         Doc->highlightWireLabels();
         Doc->viewport()->update();
-        drawn = false;
     }
 }
 
@@ -1648,7 +1673,6 @@ void MouseActions::MPressMoveText(Schematic *Doc, QMouseEvent *, float fX, float
         MAx1 = ((Component *) focusElement)->cx + ((Component *) focusElement)->tx;
         MAy1 = ((Component *) focusElement)->cy + ((Component *) focusElement)->ty;
         Doc->viewport()->update();
-        drawn = false;
         QucsMain->MouseMoveAction = &MouseActions::MMoveMoveText;
         QucsMain->MouseReleaseAction = &MouseActions::MReleaseMoveText;
         Doc->grabKeyboard(); // no keyboard inputs during move actions
@@ -1668,7 +1692,6 @@ void MouseActions::MPressZoomIn(Schematic *Doc, QMouseEvent *, float fX, float f
     QucsMain->MouseReleaseAction = &MouseActions::MReleaseZoomIn;
     Doc->grabKeyboard(); // no keyboard inputs during move actions
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // ***********************************************************************
@@ -1701,7 +1724,6 @@ void MouseActions::MReleaseSelect(Schematic *Doc, QMouseEvent *Event)
     QucsMain->MouseMoveAction = 0; // no element moving
     Doc->highlightWireLabels();
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1715,7 +1737,8 @@ void MouseActions::MReleaseSelect2(Schematic *Doc, QMouseEvent *Event)
     bool IsShift = Event->modifiers().testFlag(Qt::ShiftModifier);
 
     // selects all elements within the rectangle
-    Doc->selectElements(MAx1, MAy1, MAx1 + MAx2, MAy1 + MAy2, IsCtrl, !IsShift);
+    Doc->selectElements(
+        QRect{MAx1, MAy1, MAx2, MAy2}.normalized(), IsCtrl, !IsShift);
 
     Doc->releaseKeyboard(); // allow keyboard inputs again
     QucsMain->MouseMoveAction = 0;
@@ -1725,7 +1748,6 @@ void MouseActions::MReleaseSelect2(Schematic *Doc, QMouseEvent *Event)
     Doc->highlightWireLabels();
     Doc->PostedPaintEvents.clear();
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1743,7 +1765,6 @@ void MouseActions::MReleaseActivate(Schematic *Doc, QMouseEvent *Event)
     QucsMain->MouseDoubleClickAction = 0;
     Doc->highlightWireLabels();
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -1759,6 +1780,10 @@ void MouseActions::MReleaseMoving(Schematic *Doc, QMouseEvent *)
     QucsMain->MousePressAction = &MouseActions::MPressSelect;
     QucsMain->MouseReleaseAction = &MouseActions::MReleaseSelect;
     QucsMain->MouseDoubleClickAction = &MouseActions::MDoubleClickSelect;
+    QucsMain->editRotate->setChecked(false);
+    QucsMain->editRotate->blockSignals(false);
+    QucsMain->insLabel->blockSignals(false);
+    QucsMain->setMarker->blockSignals(false);
 }
 
 // -----------------------------------------------------------
@@ -1813,7 +1838,6 @@ void MouseActions::MReleaseResizeDiagram(Schematic *Doc, QMouseEvent *Event)
     Doc->releaseKeyboard(); // allow keyboard inputs again
 
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1830,7 +1854,6 @@ void MouseActions::MReleaseResizePainting(Schematic *Doc, QMouseEvent *Event)
     Doc->releaseKeyboard(); // allow keyboard inputs again
 
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -1840,8 +1863,9 @@ void MouseActions::MReleaseSetLimits(Schematic *Doc, QMouseEvent *Event)
     Doc->releaseKeyboard();
 
     // TODO: Make a point version of DOC_n_POS.
-    MAx2 = DOC_X_POS(Event->pos().x());
-    MAy2 = DOC_Y_POS(Event->pos().y());
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MAx2 = inModel.x();
+    MAy2 = inModel.y();
 
     qDebug() << "Mouse released after setting limits.";
     // Check to see if the mouse is within a diagram using the oddly named "getSelected".
@@ -1983,7 +2007,7 @@ void MouseActions::MReleasePaste(Schematic *Doc, QMouseEvent *Event)
             case isAnalogComponent:
             case isDigitalComponent:
                 Doc->insertComponent((Component *) pe);
-                ((Component *) pe)->entireBounds(x1, y1, x2, y2, Doc->textCorr());
+                ((Component *) pe)->entireBounds(x1, y1, x2, y2);
                 Doc->enlargeView(x1, y1, x2, y2);
                 break;
             }
@@ -2001,27 +2025,24 @@ void MouseActions::MReleasePaste(Schematic *Doc, QMouseEvent *Event)
         QucsMain->MouseReleaseAction = 0;
         QucsMain->MouseDoubleClickAction = 0;
 
-        drawn = false;
         Doc->viewport()->update();
         Doc->setChanged(true, true);
         break;
 
     // ............................................................
-    case Qt::RightButton: // right button rotates the elements
+    case Qt::RightButton: {// right button rotates the elements
         //setPainter(Doc, &painter);
 
-        if (drawn) // erase old scheme
-            paintElementsScheme(Doc);
-        drawn = true;
-
-        x1 = DOC_X_POS(Event->pos().x());
-        y1 = DOC_Y_POS(Event->pos().y());
+        auto inModel = Doc->contentsToModel(Event->pos());
+        x1 = inModel.x();
+        y1 = inModel.y();
         rotateElements(Doc, x1, y1);
         paintElementsScheme(Doc);
         // save rotation
         movingRotated++;
         movingRotated &= 3;
         break;
+    }
 
     default:; // avoids compiler warnings
     }
@@ -2040,7 +2061,6 @@ void MouseActions::MReleaseMoveText(Schematic *Doc, QMouseEvent *Event)
     ((Component *) focusElement)->tx = MAx1 - ((Component *) focusElement)->cx;
     ((Component *) focusElement)->ty = MAy1 - ((Component *) focusElement)->cy;
     Doc->viewport()->update();
-    drawn = false;
     Doc->setChanged(true, true);
 }
 
@@ -2085,7 +2105,9 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
     int x1, y1, x2, y2;
 
     QFileInfo Info(Doc->DocName);
-    float fX = DOC_X_FPOS, fY = DOC_Y_FPOS;
+    auto inModel = Doc->contentsToModel(Event->pos());
+    float fX = static_cast<float>(inModel.x());
+    float fY = static_cast<float>(inModel.y());
 
     switch (focusElement->Type) {
     case isComponent:
@@ -2096,7 +2118,12 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
         if (c->Model == "GND")
             return;
 
-        if ((c->Model == ".CUSTOMSIM") || (c->Model == ".XYCESCR") || (c->Model == "INCLSCR")) {
+        if (c->Model == "SpLib") {
+          SpiceLibCompDialog *sld = new SpiceLibCompDialog(c, Doc);
+          if (sld->exec() != -1) {
+            break;
+          }
+        } else if ((c->Model == ".CUSTOMSIM") || (c->Model == ".XYCESCR") || (c->Model == "INCLSCR")) {
             CustomSimDialog *sd = new CustomSimDialog((SpiceCustomSim *) c, Doc);
             if (sd->exec() != 1)
                 break; // dialog is WDestructiveClose
@@ -2124,13 +2151,14 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
         }
 
         Doc->setChanged(true, true);
-        c->entireBounds(x1, y1, x2, y2, Doc->textCorr());
+        c->entireBounds(x1, y1, x2, y2);
         Doc->enlargeView(x1, y1, x2, y2);
         break;
 
     case isDiagram:
         dia = (Diagram *) focusElement;
-        if (dia->Name.at(0) == 'T') { // don't open dialog on scrollbar
+        if (dia->Name.at(0) == 'T' // check only on double click
+            && Event->type() == QMouseEvent::MouseButtonDblClick) { // don't open dialog on scrollbar
             if (dia->Name == "Time") {
                 if (dia->cy < int(fY)) {
                     if (((TimingDiagram *) focusElement)->scroll(MAx1))
@@ -2199,7 +2227,6 @@ void MouseActions::editElement(Schematic *Doc, QMouseEvent *Event)
     Doc->setFocus();
 
     Doc->viewport()->update();
-    drawn = false;
 }
 
 // -----------------------------------------------------------
@@ -2217,7 +2244,8 @@ void MouseActions::MDoubleClickSelect(Schematic *Doc, QMouseEvent *Event)
  */
 void MouseActions::MDoubleClickWire2(Schematic *Doc, QMouseEvent *Event)
 {
-    MPressWire2(Doc, Event, DOC_X_FPOS, DOC_Y_FPOS);
+    auto inModel = Doc->contentsToModel(Event->pos());
+    MPressWire2(Doc, Event, static_cast<float>(inModel.x()), static_cast<float>(inModel.y()));
 
     if (formerAction)
         QucsMain->select->setChecked(true); // restore old action
@@ -2278,7 +2306,7 @@ void MouseActions::MPressTune(Schematic *Doc, QMouseEvent *Event, float fX, floa
         if (pc == nullptr || pp == nullptr)
             return;
         if (!App->tunerDia->containsProperty(pp)) {
-            if (checkProperty(pc, pp)) {
+            if (isPropertyTunable(pc, pp)) {
                 tunerElement *tune = new tunerElement(App->tunerDia, pc, pp, No);
                 tune->schematicName = Doc->DocName;
                 if (tune != NULL)
