@@ -42,28 +42,27 @@ qucs::Rectangle::~Rectangle()
 {
 }
 
-// --------------------------------------------------------------------------
-void qucs::Rectangle::paint(ViewPainter *p)
-{
-  if(isSelected) {
-    p->Painter->setPen(QPen(Qt::darkGray,Pen.width()+5));
-    if(filled)  p->Painter->setBrush(Brush);
-    p->drawRect(cx, cy, x2, y2);
-    p->Painter->setPen(QPen(Qt::white, Pen.width(), Pen.style()));
-    p->Painter->setBrush(Qt::NoBrush);
-    p->drawRect(cx, cy, x2, y2);
+void qucs::Rectangle::paint(QPainter *painter) {
+  painter->save();
 
-    p->Painter->setPen(QPen(Qt::darkRed,2));
-    p->drawResizeRect(cx, cy+y2);  // markers for changing the size
-    p->drawResizeRect(cx, cy);
-    p->drawResizeRect(cx+x2, cy+y2);
-    p->drawResizeRect(cx+x2, cy);
-    return;
+  painter->setPen(Pen);
+  if (filled) {
+    painter->setBrush(Brush);
   }
-  p->Painter->setPen(Pen);
-  if(filled)  p->Painter->setBrush(Brush);
-  p->drawRect(cx, cy, x2, y2);
-  p->Painter->setBrush(Qt::NoBrush); // no filling for the next paintings
+  painter->drawRect(cx, cy, x2, y2);
+
+  if (isSelected) {
+    painter->setPen(QPen(Qt::darkGray,Pen.width()+5));
+    painter->drawRect(cx, cy, x2, y2);
+    painter->setPen(QPen(Qt::white, Pen.width(), Pen.style()));
+    painter->drawRect(cx, cy, x2, y2);
+
+    misc::draw_resize_handle(painter, QPoint{cx, cy});
+    misc::draw_resize_handle(painter, QPoint{cx, cy + y2});
+    misc::draw_resize_handle(painter, QPoint{cx + x2, cy});
+    misc::draw_resize_handle(painter, QPoint{cx + x2, cy + y2});
+  }
+  painter->restore();
 }
 
 // --------------------------------------------------------------------------
@@ -259,7 +258,7 @@ void qucs::Rectangle::MouseResizeMoving(int x, int y, Schematic *p)
 // x/y are coordinates without scaling.
 void qucs::Rectangle::MouseMoving(
 	Schematic *paintScale, int, int, int gx, int gy,
-	Schematic *p, int x, int y, bool drawn)
+	Schematic *p, int x, int y)
 {
   if(State > 0) {
     if(State > 1)
@@ -271,16 +270,6 @@ void qucs::Rectangle::MouseMoving(
   }
   else { x2 = gx; y2 = gy; }
 
-
-  // FIXME #warning p->setPen(Qt::SolidLine);
-  if(drawn) {
-    p->PostPaintEvent(_Rect, cx+13, cy, 18, 12,0,0,true);  // erase old cursor symbol
-    if(filled) {   // hatched ?
-      p->PostPaintEvent(_Line, cx+14, cy+6, cx+19, cy+1,0,0,true);
-      p->PostPaintEvent(_Line, cx+26, cy+1, cx+17, cy+10,0,0,true);
-      p->PostPaintEvent(_Line, cx+29, cy+5, cx+24, cy+10,0,0,true);
-    }
-  }
   cx = x;
   cy = y;
   p->PostPaintEvent(_Rect,cx+13, cy, 18, 12,0,0,true);  // paint new cursor symbol
