@@ -41,6 +41,7 @@
 #include <QListWidget>
 #include <QDesktopServices>
 
+#include "portsymbol.h"
 #include "projectView.h"
 #include "main.h"
 #include "qucs.h"
@@ -58,7 +59,6 @@
 #include "dialogs/librarydialog.h"
 #include "dialogs/loaddialog.h"
 #include "dialogs/importdialog.h"
-#include "dialogs/packagedialog.h"
 #include "dialogs/aboutdialog.h"
 #include "module.h"
 
@@ -117,7 +117,6 @@ bool QucsApp::performToggleAction(bool on, QAction *Action,
   } while(false);   // to perform "break"
 
   Doc->viewport()->update();
-  view->drawn = false;
   return true;
 }
 
@@ -299,7 +298,6 @@ void QucsApp::slotSelect(bool on)
     MouseMoveAction = &MouseActions::MMoveWire1;
     MousePressAction = &MouseActions::MPressWire1;
     Doc->viewport()->update();
-    view->drawn = false;
 
     select->blockSignals(true);
     select->setChecked(false);
@@ -373,9 +371,6 @@ void QucsApp::slotEditPaste(bool on)
       MouseReleaseAction = 0;
       MouseDoubleClickAction = 0;
       activeAction = 0;   // no action active
-      if(view->drawn) {
-        ((Schematic *)Doc)->viewport()->update();
-      }
       return;
     }
 
@@ -395,7 +390,6 @@ void QucsApp::slotEditPaste(bool on)
     }
     activeAction = editPaste;
 
-    view->drawn = false;
     MouseMoveAction = &MouseActions::MMovePaste;
     view->movingRotated = 0;
     MousePressAction = 0;
@@ -449,9 +443,6 @@ void QucsApp::slotInsertEquation(bool on)
       view->selElem = new Equation();
   }
 
-  Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
-  if(view->drawn) Doc->viewport()->update();
-  view->drawn = false;
   MouseMoveAction = &MouseActions::MMoveElement;
   MousePressAction = &MouseActions::MPressElement;
 }
@@ -482,9 +473,6 @@ void QucsApp::slotInsertGround(bool on)
 
   view->selElem = new Ground();
 
-  Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
-  if(view->drawn) Doc->viewport()->update();
-  view->drawn = false;
   MouseMoveAction = &MouseActions::MMoveElement;
   MousePressAction = &MouseActions::MPressElement;
 }
@@ -513,11 +501,13 @@ void QucsApp::slotInsertPort(bool on)
   if(view->selElem)
     delete view->selElem;  // delete previously selected component
 
-  view->selElem = new SubCirPort();
-
   Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
-  if(view->drawn) Doc->viewport()->update();
-  view->drawn = false;
+  if (Doc->symbolMode) {
+    view->selElem = new PortSymbol();
+  } else {
+     view->selElem = new SubCirPort();
+  }
+
   MouseMoveAction = &MouseActions::MMoveElement;
   MousePressAction = &MouseActions::MPressElement;
 }
@@ -537,7 +527,6 @@ void QucsApp::slotEditUndo()
 
   Doc->undo();
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -555,7 +544,6 @@ void QucsApp::slotEditRedo()
 
   Doc->redo();
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -569,7 +557,6 @@ void QucsApp::slotAlignTop()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -583,7 +570,6 @@ void QucsApp::slotAlignBottom()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -597,7 +583,6 @@ void QucsApp::slotAlignLeft()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -611,7 +596,6 @@ void QucsApp::slotAlignRight()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -623,7 +607,6 @@ void QucsApp::slotDistribHoriz()
   Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
   Doc->distributeHorizontal();
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -635,7 +618,6 @@ void QucsApp::slotDistribVert()
   Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
   Doc->distributeVertical();
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -649,7 +631,6 @@ void QucsApp::slotCenterHorizontal()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // --------------------------------------------------------------
@@ -663,7 +644,6 @@ void QucsApp::slotCenterVertical()
     QMessageBox::information(this, tr("Info"),
 		      tr("At least two elements must be selected !"));
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 // ---------------------------------------------------------------------
@@ -679,15 +659,9 @@ void QucsApp::slotSelectAll()
     ((TextDoc*)Doc)->selectAll();
   }
   else {
-    int xmin, ymin, xmax, ymax;
-    ((Schematic*)Doc)->sizeOfAll(xmin, ymin, xmax, ymax);
-    xmin--;
-    ymin--;
-    xmax++;
-    ymax++;
-    ((Schematic*)Doc)->selectElements(xmin, ymin, xmax, ymax, true, false);
+    auto selectionRect = ((Schematic*)Doc)->allBoundingRect().marginsAdded(QMargins{1, 1, 1, 1});
+    ((Schematic*)Doc)->selectElements(selectionRect, true, false);
     ((Schematic*)Doc)->viewport()->update();
-    view->drawn = false;
   }
 }
 
@@ -700,7 +674,6 @@ void QucsApp::slotSelectMarker()
   Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
   Doc->selectMarkers();
   Doc->viewport()->update();
-  view->drawn = false;
 }
 
 
@@ -742,7 +715,7 @@ void QucsApp::editFile(const QString& File)
 
       if (QucsSettings.Editor.toLower().contains("qucsedit")) {
 
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
   prog = QUCS_NAME"edit.exe";
 #elif __APPLE__
   prog = "qucsedit.app/Contents/MacOS/qucsedit";
@@ -787,7 +760,7 @@ void QucsApp::editFile(const QString& File)
 // Is called to show the output messages of the last simulation.
 void QucsApp::slotShowLastMsg()
 {
-  editFile(QucsSettings.QucsHomeDir.filePath("log.txt"));
+  editFile(QucsSettings.tempFilesDir.filePath("log.txt"));
 }
 
 // ------------------------------------------------------------------------
@@ -814,7 +787,7 @@ void QucsApp::slotShowLastNetlist()
 
     switch (QucsSettings.DefaultSimulator) {
     case spicecompat::simQucsator :
-        netlists.append(QucsSettings.QucsHomeDir.filePath("netlist.txt"));
+        netlists.append(QucsSettings.tempFilesDir.filePath("netlist.txt"));
         break;
     case spicecompat::simNgspice :
     case spicecompat::simSpiceOpus :
@@ -835,7 +808,7 @@ void QucsApp::slotShowLastNetlist()
         Schematic *sch = (Schematic *) w;
         if (sch->isDigitalCircuit()) {
             netlists.clear();
-            netlists.append(QucsSettings.QucsHomeDir.filePath("netlist.txt"));
+            netlists.append(QucsSettings.tempFilesDir.filePath("netlist.txt"));
         }
     }
 
@@ -848,7 +821,7 @@ void QucsApp::slotShowLastNetlist()
 // Is called to start the text editor.
 void QucsApp::slotCallEditor()
 {
-  editFile(QString(""));
+  editFile(QString());
 }
 
 // ------------------------------------------------------------------------
@@ -890,6 +863,11 @@ void QucsApp::slotCallPwrComb()
   launchTool(QUCS_NAME "powercombining", "power combining calculation",QStringList());
 }
 
+void QucsApp::slotCallSPAR_Viewer()
+{
+  launchTool(QUCS_NAME "spar-viewer", "s-parameter viewer",QStringList());
+}
+
 
 /*!
  * \brief launch an external application passing arguments
@@ -906,7 +884,7 @@ void QucsApp::launchTool(const QString& prog, const QString& progDesc, const QSt
   QString tooldir;
   if (qucs_tool) tooldir = QucsSettings.QucsatorDir;
   else tooldir = QucsSettings.BinDir;
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
   QString cmd = QDir::toNativeSeparators("\""+tooldir + prog + ".exe\"");
 #elif __APPLE__
   QString cmd = QDir::toNativeSeparators(tooldir + prog + ".app/Contents/MacOS/" + prog);
@@ -930,6 +908,64 @@ void QucsApp::launchTool(const QString& prog, const QString& progDesc, const QSt
 }
 
 
+void QucsApp::slotCallRFLayout()
+{
+    QString input_file, netlist_file, odir;
+    if (!isTextDocument(DocumentTab->currentWidget())) {
+        Schematic *sch = (Schematic*)DocumentTab->currentWidget();
+        if(sch->fileSuffix() == "dpl") {
+            QMessageBox::critical(this,tr("Error"),
+                                  tr("Layouting of display pages is not supported!"));
+            return;
+        }
+        input_file = sch->DocName;
+        QFileInfo inf(sch->DocName);
+        odir = inf.absolutePath();
+        netlist_file = inf.absolutePath() + QDir::separator()
+                + inf.baseName() + ".net";
+        QFile f(netlist_file);
+        if (!f.open(QIODevice::WriteOnly)) {
+            QMessageBox::critical(this, tr("Error"), tr("Cannot write netlist!"));
+            return;
+        }
+        QTextStream stream(&f);
+        QStringList Collect;
+        QPlainTextEdit *ErrText = new QPlainTextEdit();  //dummy
+        int pNum = sch->prepareNetlist(stream, Collect, ErrText);
+        if (!sch->isAnalog) {
+            QMessageBox::critical(this, tr("Error"), tr("Digital schematic not supported!"));
+            return;
+        }
+        stream << '\n';
+        sch->createNetlist(stream, pNum);
+        f.close();
+    } else {
+        QMessageBox::critical(this,tr("Error"),
+                              tr("Layouting of text documents is not supported!"));
+        return;
+    }
+
+    QProcess *tool = new QProcess();
+    QStringList args;
+    args.append("-G");
+    args.append("-i");
+    args.append(input_file);
+    args.append("-n");
+    args.append(netlist_file);
+    args.append("-o");
+    args.append(odir);
+    tool->start(QucsSettings.RFLayoutExecutable,args);
+
+    if(!tool->waitForStarted(1000) ) {
+      QMessageBox::critical(this, tr("Error"),
+                            tr("Cannot start Qucs-RFLayout: \n%1")
+                            .arg(QucsSettings.RFLayoutExecutable));
+      delete tool;
+      return;
+    }
+    connect(this, SIGNAL(signalKillEmAll()), tool, SLOT(kill()));
+}
+
 // --------------------------------------------------------------
 void QucsApp::slotHelpIndex()
 {
@@ -1077,11 +1113,10 @@ void QucsApp::slotCursorLeft(bool left)
     } else if(left) {
       Doc->scrollLeft(Doc->horizontalScrollBar()->singleStep());
     }else{ // right
-      Doc->scrollRight(-Doc->horizontalScrollBar()->singleStep());
+      Doc->scrollRight(Doc->horizontalScrollBar()->singleStep());
     }
 
     Doc->viewport()->update();
-    view->drawn = false;
     return;
   } else { // random selection. move all of them
     view->moveElements(&movingElements, sign*Doc->GridX, 0);
@@ -1148,7 +1183,6 @@ void QucsApp::slotCursorUp(bool up)
     }
 
     Doc->viewport()->update();
-    view->drawn = false;
     return;
   }else{ // some random selection, put it back
     view->moveElements(&movingElements, 0, ((up)?-1:1) * Doc->GridY);
@@ -1163,110 +1197,94 @@ void QucsApp::slotCursorUp(bool up)
 // In "view->MAx3" is the number of the current property.
 void QucsApp::slotApplyCompText()
 {
-  QString s;
   QFont f = QucsSettings.font;
   Schematic *Doc = (Schematic*)DocumentTab->currentWidget();
   f.setPointSizeF( Doc->Scale * float(f.pointSize()) );
   editText->setFont(f);
 
-  Property  *pp = 0;
-  Component *pc = (Component*)view->focusElement;
-  if(!pc) return;  // should never happen
-  view->MAx1 = pc->cx + pc->tx;
-  view->MAy1 = pc->cy + pc->ty;
+  Component *const component = dynamic_cast<Component*>(view->focusElement);
+  if(!component) return;  // should never happen
+  view->MAx1 = component->cx + component->tx;
+  view->MAy1 = component->cy + component->ty;
 
-  int z, n=0;  // "n" is number of property on screen
-  pp = pc->Props.first();
-  for(z=view->MAx3; z>0; z--) {  // calculate "n"
-    if(!pp) {  // should never happen
-      slotHideEdit();
-      return;
-    }
-    if(pp->display) n++;   // is visible ?
-    pp = pc->Props.next();
-  }
+  // Here is a bit of *magic* and implicit coupling: the value of view->MAx3
+  // comes from Component::getTextSelected, and it's equal 0 when component
+  // name is clicked, N + 1 when Nth component property is clicked.
+  const int component_text_index = view->MAx3;
+  const bool is_name = component_text_index == 0;
 
-  pp = 0;
-  if(view->MAx3 > 0)  pp = pc->Props.at(view->MAx3-1); // current property
-  else s = pc->Name;
+  Property *const component_property = !is_name
+                                     ? component->Props.at(component_text_index - 1)
+                                     : nullptr;
 
-  if(!editText->isHidden()) {   // is called the first time ?
-    // no -> apply value to current property
-    if(view->MAx3 == 0) {   // component name ?
-      Component *pc2;
-      if(!editText->text().isEmpty())
-        if(pc->Name != editText->text()) {
-          for(pc2 = Doc->Components->first(); pc2!=0; pc2 = Doc->Components->next())
-            if(pc2->Name == editText->text())
-              break;  // found component with the same name ?
-          if(!pc2) {
-            pc->Name = editText->text();
-            Doc->setChanged(true, true);  // only one undo state
+  if (editText->isVisible()) {   // is called the first time ?
+    if (is_name) {
+      const auto new_name{editText->text()};
+
+      if (!new_name.isEmpty() && component->Name != new_name) {
+        // TODO: rewrite with std::none_of after replacing Q3PtrList
+        //       with modern container
+        bool is_unique = true;
+        for (auto* other : *Doc->Components) {
+          if (other->Name == new_name) {
+            is_unique = false;
+            break;
           }
         }
+
+        if (is_unique) {
+          component->Name = new_name;
+          Doc->setChanged(true, true);  // only one undo state
+        }
+      }
+
     }
-    else if(pp) {  // property was applied
-      if(pp->Value != editText->text()) {
-        pp->Value = editText->text();
-        Doc->recreateComponent(pc);  // because of "Num" and schematic symbol
+    else if (component_property) {  // property was applied
+      if (component_property->Value != editText->text()) {
+        component_property->Value = editText->text();
+        Doc->recreateComponent(component);  // because of "Num" and schematic symbol
         Doc->setChanged(true, true); // only one undo state
       }
     }
-
-    n++;     // next row on screen
-    (view->MAx3)++;  // next property
-    pp = pc->Props.at(view->MAx3-1);  // search for next property
-
-    Doc->viewport()->update();
-    view->drawn = false;
-
-    if(!pp) {     // was already last property ?
-      slotHideEdit();
-      return;
-    }
-
-
-    while(!pp->display) {  // search for next visible property
-      (view->MAx3)++;  // next property
-      pp = pc->Props.next();
-      if(!pp) {     // was already last property ?
-        slotHideEdit();
-        return;
-      }
-    }
   }
 
-  // avoid seeing the property text behind the line edit
-  if(pp)  // Is it first property or component name ?
-    s = pp->Value;
-  editText->setMinimumWidth(editText->fontMetrics().boundingRect(s).width()+4);
+  const QString s = is_name
+                ? component->Name
+                : component_property->Value;
 
-
-  Doc->contentsToViewport(int(Doc->Scale * float(view->MAx1 - Doc->ViewX1)),
-			 int(Doc->Scale * float(view->MAy1 - Doc->ViewY1)),
-			 view->MAx2, view->MAy2);
   editText->setReadOnly(false);
-  if(pp) {  // is it a property ?
-    s = pp->Value;
-    view->MAx2 += editText->fontMetrics().boundingRect(pp->Name+"=").width();
-    if(pp->Description.indexOf('[') >= 0)  // is selection list ?
+  QPoint editTextTopLeft;
+  if (component_property) {  // is it a property ?
+    editTextTopLeft = Doc->modelToViewport(QPoint{component->cx, component->cy} + component_property->boundingRect().topLeft());
+    editTextTopLeft.rx() += editText->fontMetrics().boundingRect(component_property->Name + "=" + '\u0020').width();
+
+    if(component_property->Description.indexOf('[') >= 0)  // is selection list ?
       editText->setReadOnly(true);
     Expr_CompProp.setPattern("[^\"]*");
-    if(!pc->showName) n--;
   }
-  else   // it is the component name
+  else { // it is the component name
     Expr_CompProp.setPattern("[\\w_]+");
+    editTextTopLeft = Doc->modelToViewport(QPoint{component->cx + component->tx, component->cy + component->ty});
+  }
+
+  {
+    auto size = editText->fontMetrics().boundingRect(s ).size();
+    size.rwidth() += editText->fontMetrics().averageCharWidth();
+    editText->setFixedSize(size);
+  }
+
+  view->MAx2 = editTextTopLeft.x();
+  view->MAy2 = editTextTopLeft.y();
+
   Val_CompProp.setRegularExpression(Expr_CompProp);
   editText->setValidator(&Val_CompProp);
 
-  z = editText->fontMetrics().lineSpacing();
-  view->MAy2 += n*z;
   editText->setText(s);
-  misc::setWidgetBackgroundColor(editText,QucsSettings.BGColor);
+  editText->setStyleSheet("color: black; background-color: " + QucsSettings.BGColor.name());
   editText->setFocus();
   editText->selectAll();
   editText->setParent(Doc->viewport());
-  editText->move(QPoint(view->MAx2, view->MAy2));
+  editText->move(view->MAx2, view->MAy2);
   editText->show();
   //editText->reparent(Doc->viewport(), 0, QPoint(view->MAx2, view->MAy2), true);
 }
@@ -1292,7 +1310,10 @@ void QucsApp::slotCreateLib()
 
   LibraryDialog *d = new LibraryDialog(this);
   d->fillSchematicList(Content->exportSchematic());
-  d->exec();
+  auto r = d->exec();
+  if (r != QDialog::Accepted) {
+    fillLibrariesTreeView();
+  }
 }
 
 // -----------------------------------------------------------
@@ -1300,12 +1321,26 @@ void QucsApp::slotImportData()
 {
   slotHideEdit(); // disable text edit of component property
 
-  if(ProjName.isEmpty()) {
-    QMessageBox::critical(this, tr("Error"), tr("Please open project first!"));
-    return;
+  QString import_dir = ".";
+  if (!ProjName.isEmpty()) {
+      import_dir = QucsSettings.QucsWorkDir.absolutePath();
+  } else {
+      QString dname;
+      if (isTextDocument(DocumentTab->currentWidget())) {
+          TextDoc *doc = (TextDoc *)DocumentTab->currentWidget();
+          dname = doc->DocName;
+      } else {
+          Schematic *doc = (Schematic *)DocumentTab->currentWidget();
+          dname = doc->DocName;
+      }
+      QFileInfo inf(dname);
+      if (inf.exists()) {
+          import_dir = inf.absolutePath();
+      }
   }
 
   ImportDialog *d = new ImportDialog(this);
+  d->setImportDir(import_dir);
   if(d->exec() == QDialog::Accepted)
     slotUpdateTreeview();
 }
@@ -1381,24 +1416,6 @@ void QucsApp::slotExportGraphAsCsv()
   File.close();
 }
 
-// ----------------------------------------------------------
-void QucsApp::slotCreatePackage()
-{
-  slotHideEdit(); // disable text edit of component property
-
-  PackageDialog *d = new PackageDialog(this, true);
-  d->exec();
-}
-
-// ----------------------------------------------------------
-void QucsApp::slotExtractPackage()
-{
-  slotHideEdit(); // disable text edit of component property
-  PackageDialog *d = new PackageDialog(this, false);
-  d->show();
-  d->extractPackage();
-  readProjects();
-}
 
 void QucsApp::slotOpenRecent()
 {
@@ -1559,7 +1576,7 @@ void QucsApp::slotBuildModule()
 
     QString make;
 
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
     make = "mingw32-make.exe";    // must be on the path!
 #else
     make = "make";                // must be on the path!
@@ -1585,7 +1602,7 @@ void QucsApp::slotBuildModule()
 
     QString admsXml = QucsSettings.AdmsXmlBinDir.canonicalPath();
 
-#ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
     admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml.exe");
 #else
     admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml");
