@@ -567,6 +567,18 @@ int Schematic::saveDocument()
 
   stream << "<Qucs Schematic " << PACKAGE_VERSION << ">\n";
 
+  // Special case of saving a file when we want to save *only*
+  // the symbol defintion (i.e. to create a "symbol file")
+  if (DocName.endsWith(".sym")) {
+      stream << "<Symbol>\n";
+      for(auto* pp : SymbolPaints) {
+          stream << "  <" << pp->save() << ">\n";
+      }
+      stream << "</Symbol>\n";
+      file.close();
+      return 0;
+  }
+
   stream << "<Properties>\n";
   if(symbolMode) {
     stream << "  <View=" << tmpViewX1<<","<<tmpViewY1<<","
@@ -654,7 +666,7 @@ int Schematic::saveDocument()
           //pick admsXml from settings
           QString admsXml = QucsSettings.AdmsXmlBinDir.canonicalPath();
 
-    #ifdef __MINGW32__
+#if defined(_WIN32) || defined(__MINGW32__)
           admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml.exe");
     #else
           admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml");
@@ -664,7 +676,7 @@ int Schematic::saveDocument()
 
           qDebug() << "App path : " << qApp->applicationDirPath();
           qDebug() << "workdir"  << workDir;
-          qDebug() << "homedir"  << QucsSettings.QucsHomeDir.absolutePath();
+          qDebug() << "workspacedir"  << QucsSettings.qucsWorkspaceDir.absolutePath();
 
           vaFile = QucsSettings.QucsWorkDir.filePath(fileBase()+".va");
 
@@ -839,7 +851,7 @@ void Schematic::simpleInsertComponent(Component *c)
       pn = new Node(x, y);
       DocNodes.append(pn);
     }
-    pn->Connections.append(c);  // connect schematic node to component node
+    pn->connect(c);  // connect schematic node to component node
     if (!pp->Type.isEmpty()) {
       pn->DType = pp->Type;
     }
@@ -903,7 +915,7 @@ void Schematic::simpleInsertWire(Wire *pw)
     delete pw;           // delete wire because this is not a wire
     return;
   }
-  pn->Connections.append(pw);  // connect schematic node to component node
+  pn->connect(pw);  // connect schematic node to component node
   pw->Port1 = pn;
 
   // check if second wire node lies upon existing node
@@ -914,7 +926,7 @@ void Schematic::simpleInsertWire(Wire *pw)
     pn = new Node(pw->x2, pw->y2);
     DocNodes.append(pn);
   }
-  pn->Connections.append(pw);  // connect schematic node to component node
+  pn->connect(pw);  // connect schematic node to component node
   pw->Port2 = pn;
 
   DocWires.append(pw);
@@ -1058,7 +1070,7 @@ bool Schematic::loadDocument()
   QFile file(DocName);
   if(!file.open(QIODevice::ReadOnly)) {
     /// \todo implement unified error/warning handling GUI and CLI
-    if (QucsMain)
+    if (QucsMain != nullptr)
       QMessageBox::critical(0, QObject::tr("Error"),
                  QObject::tr("Cannot load document: ")+DocName);
     else
@@ -1384,11 +1396,10 @@ void Schematic::propagateNode(QStringList& Collect,
   Q3PtrList<Node> Cons;
   Node *p2;
   Wire *pw;
-  Element *pe;
 
   Cons.append(pn);
   for(p2 = Cons.first(); p2 != 0; p2 = Cons.next())
-    for(pe = p2->Connections.first(); pe != 0; pe = p2->Connections.next())
+    for(auto* pe : *p2)
       if(pe->Type == isWire) {
 	pw = (Wire*)pe;
 	if(p2 != pw->Port1) {
@@ -1498,7 +1509,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
           delete d;
           /// \todo implement error/warning message dispatcher for GUI and CLI modes.
           QString message = QObject::tr("ERROR: Cannot load subcircuit \"%1\".").arg(s);
-          if (QucsMain) // GUI is running
+          if (QucsMain != nullptr) // GUI is running
             ErrText->appendPlainText(message);
           else // command line
             qCritical() << "Schematic::throughAllComps" << message;
@@ -1617,7 +1628,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
 	continue;
       if(!isVerilog && pc->Model == "Verilog")
 	continue;
-      s = pc->Props.getFirst()->Value;
+      s = pc->Props.front()->Value;
       if(s.isEmpty()) {
         ErrText->appendPlainText(QObject::tr("ERROR: No file name in %1 component \"%2\".").
 			arg(pc->Model).
@@ -2093,9 +2104,9 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
              QObject::tr("ERROR: Only one digital simulation allowed."));
           return -10;
         }
-        if(pc->Props.getFirst()->Value != "TimeList")
+        if(pc->Props.front()->Value != "TimeList")
           isTruthTable = true;
-	      if(pc->Props.getLast()->Value != "VHDL")
+	      if(pc->Props.back()->Value != "VHDL")
 	        isVerilog = true;
         allTypes |= isDigitalComponent;
 	      isAnalog = false;
@@ -2134,15 +2145,21 @@ int Schematic::prepareNetlist(QTextStream& stream, QStringList& Collect,
   }
 
   // first line is documentation
+  bool has_header = true;
   if(allTypes & isAnalogComponent) {
-    if (QucsSettings.DefaultSimulator != spicecompat::simQucsator)
-        stream << "*";
-    else stream << '#';
-  } else if (isVerilog)
+    if (QucsSettings.DefaultSimulator != spicecompat::simQucsator) {
+      has_header = false;
+    } else {
+      stream << '#';
+    }
+  } else if (isVerilog) {
     stream << "//";
-  else
+  } else {
     stream << "--";
-  stream << " Qucs " << PACKAGE_VERSION << "  " << DocName << "\n";
+  }
+  if (has_header) {
+    stream << " Qucs " << PACKAGE_VERSION << "  " << DocName << "\n";
+  }
 
   // set timescale property for verilog schematics
   if (isVerilog) {
