@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "BJT_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -184,7 +183,7 @@ Element* BJT_SPICE::infoPNP5(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString BJT_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString BJT_SPICE::spice_netlist(bool)
