@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "C_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -107,7 +106,7 @@ Element* C_SPICE::info_C3(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString C_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString C_SPICE::spice_netlist(bool)
