@@ -18,7 +18,6 @@
 
 #include "Icouple.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -64,7 +63,7 @@ Icouple::Icouple()
 
 
   x1 = -45; y1 = -45;
-  x2 =  50; y2 =  45;
+  x2 =  65; y2 =  45;
 
   tx = x1+5;
   ty = y2+5;
@@ -98,7 +97,7 @@ Element* Icouple::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString Icouple::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString Icouple::spice_netlist(bool)
