@@ -17,7 +17,6 @@
  ***************************************************************************/
 #include "LTL_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -86,7 +85,7 @@ Element* LTL_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString LTL_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString LTL_SPICE::spice_netlist(bool)
@@ -109,6 +108,18 @@ QString LTL_SPICE::spice_netlist(bool)
 
 
 
-    s += QString(" Z0=%1 Td=%2 F=%3 NL=%4 IC=%5, %6, %7, %8 \n").arg(Z0).arg(Td).arg(Freq).arg(Nl).arg(V1).arg(I1).arg(V2).arg(I2);
+   if( Z0.trimmed().length() > 0) {
+       s += QString(" Z0=%1").arg(Z0);
+   }
+   if( Td.trimmed().length() > 0 )  {
+       s += QString(" Td=%1").arg(Td);
+   }
+   if( Freq.trimmed().length() > 0 ) {
+       s += QString(" F=%1").arg(Freq);
+   }
+   if( Nl.trimmed().length() > 0 ) {
+       s += QString(" NL=%1").arg(Nl);
+   }
+   s += QString(" IC=%5, %6, %7, %8 \n").arg(V1).arg(I1).arg(V2).arg(I2);
     return s;
 }
