@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "LTRA_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -92,7 +91,7 @@ Element* LTRA_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString LTRA_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString LTRA_SPICE::spice_netlist(bool)
