@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "MOS_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -177,7 +176,7 @@ Element* MOS_SPICE::info_PX4pin(QString& Name, char* &BitmapFile, bool getNewOne
 
 QString MOS_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 void MOS_SPICE::createSymbol()
