@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "NJF_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -91,7 +90,7 @@ Element* NJF_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString NJF_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString NJF_SPICE::spice_netlist(bool)
