@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "NMOS_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -100,7 +99,7 @@ Element* NMOS_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString NMOS_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString NMOS_SPICE::spice_netlist(bool)
