@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "NPN_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -92,7 +91,7 @@ Element* NPN_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString NPN_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString NPN_SPICE::spice_netlist(bool)
