@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "PMF_MESFET_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -84,7 +83,7 @@ Element* PMF_MESFET_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne
 
 QString PMF_MESFET_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString PMF_MESFET_SPICE::spice_netlist(bool)
