@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "R_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 R_SPICE::R_SPICE()
@@ -111,7 +110,7 @@ Element* R_SPICE::info_R3(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString R_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString R_SPICE::spice_netlist(bool)
