@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "S4Q_S.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -37,7 +36,7 @@ S4Q_S::S4Q_S()
     Lines.append(new qucs::Line(-15,  0,   -5,  0,QPen(Qt::darkRed,3)));
     Lines.append(new qucs::Line( 30,  0,   15,  0,QPen(Qt::darkBlue,2)));
     Lines.append(new qucs::Line( 15,  0,    5,  0,QPen(Qt::darkRed,3)));
-    Lines.append(new qucs::Line(  5,  0,    0,  8,QPen(Qt::darkRed,3)));
+    Lines.append(new qucs::Line(  5,  0,    0,  8,QPen(Qt::darkRed,3, Qt::SolidLine, Qt::FlatCap)));
     Lines.append(new qucs::Line(-10, -30, -10,  -15,QPen(Qt::darkBlue,2)));
     Lines.append(new qucs::Line( 10, -30,  10,  -15,QPen(Qt::darkBlue,2)));
     
@@ -91,7 +90,7 @@ Element* S4Q_S::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 //QString S4Q_S::netlist()
 //{
- //   return QString("");
+ //   return QString();
 //}
 
 QString S4Q_S::spice_netlist(bool)
