@@ -18,7 +18,6 @@
 
 #include "SDTF.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -81,7 +80,7 @@ Element* SDTF::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString SDTF::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString SDTF::spice_netlist(bool)
