@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "UDRCTL_SPICE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -90,7 +89,7 @@ Element* UDRCTL_SPICE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString UDRCTL_SPICE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString UDRCTL_SPICE::spice_netlist(bool)
