@@ -18,7 +18,6 @@
 
 #include "gNL.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -28,13 +27,15 @@ gNL::gNL()
   Simulator = spicecompat::simSpice;
   // Value, Table and POLY forms are allowed: should work with ngspice and Xyce.
 
-  Arcs.append(new qucs::Arc(-14,-14, 28, 28,     0, 16*360,QPen(Qt::blue,3)));
-  Texts.append(new Text(30, 12,"GNL",Qt::blue,10.0,0.0,-1.0));
+  Ellipses.append(new qucs::Ellips(-12,-12, 24, 24, QPen(Qt::blue,3)));
+  Texts.append(new Text(26, 6,"GNL",Qt::blue,12.0,0.0,-1.0));
+  // pins
   Lines.append(new qucs::Line(-30,  0,-14,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 30,  0, 14,  0,QPen(Qt::darkBlue,2)));
-  Lines.append(new qucs::Line( -7,  0,  7,  0,QPen(Qt::darkBlue,3)));
-  Lines.append(new qucs::Line(  6,  0,  0, -4,QPen(Qt::darkBlue,3)));
-  Lines.append(new qucs::Line(  6,  0,  0,  4,QPen(Qt::darkBlue,3)));
+  // arrow
+  Lines.append(new qucs::Line( -7,  0,  6,  0,QPen(Qt::blue,3, Qt::SolidLine, Qt::FlatCap)));
+  Polylines.append(new qucs::Polyline(
+    std::vector<QPointF>{{0, -4},{6, 0}, {0, 4}}, QPen(Qt::blue, 3, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin)));
  
   Ports.append(new Port( 30,  0));
   Ports.append(new Port(-30,  0));
@@ -77,7 +78,7 @@ Element* gNL::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString gNL::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString gNL::spice_netlist(bool)
