@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "iPWL.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -30,13 +29,15 @@ iPWL::iPWL()
     Simulator = spicecompat::simSpice;
 
   // normal voltage source symbol
-  Arcs.append(new qucs::Arc(-12,-12, 24, 24, 0, 16*360,QPen(Qt::darkRed,3)));
-  Texts.append(new Text(30, 12,"PWL",Qt::darkRed,10.0,0.0,-1.0));
+  Ellipses.append(new qucs::Ellips(-12,-12, 24, 24, QPen(Qt::darkRed,3)));
+  Texts.append(new Text(26, 6,"PWL",Qt::darkRed,12.0,0.0,-1.0));
+  // pins
   Lines.append(new qucs::Line(-30,  0,-12,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 30,  0, 12,  0,QPen(Qt::darkBlue,2)));
-   Lines.append(new qucs::Line( -7,  0,  7,  0,QPen(Qt::darkRed,3)));
-  Lines.append(new qucs::Line(  6,  0,  0, -4,QPen(Qt::darkRed,3)));
-  Lines.append(new qucs::Line(  6,  0,  0,  4,QPen(Qt::darkRed,3)));
+  // arrow
+  Lines.append(new qucs::Line( -7,  0,  6,  0,QPen(Qt::darkRed,3, Qt::SolidLine, Qt::FlatCap)));
+  Polylines.append(new qucs::Polyline(
+    std::vector<QPointF>{{0, -4},{6, 0}, {0, 4}}, QPen(Qt::darkRed, 3, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin)));
   
 
   Ports.append(new Port( 30,  0));
@@ -86,7 +87,7 @@ Element* iPWL::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString iPWL::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString iPWL::spice_netlist(bool)
@@ -110,7 +111,7 @@ QString Line_8= Props.at(7)->Value;
 QString Line_9= Props.at(8)->Value;
 QString Line_10= Props.at(9)->Value;
 
-    s += QString("");
+    s += QString();
  
     if(  PWL.length()    > 0)    s += QString("%1").arg(PWL);
     if(  Line_2.length() > 0 )   s += QString("\n%1").arg(Line_2);
