@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "iTRNOISE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -30,19 +29,20 @@ iTRNOISE::iTRNOISE()
   Simulator = spicecompat::simSpice;
 
   // normal voltage source symbol
-  Arcs.append(new qucs::Arc(-12,-12, 24, 24,     0, 16*360,QPen(Qt::blue,3)));
-   Texts.append(new Text(36, 4,"ITRN",Qt::blue,10.0,0.0,-1.0)); 
+  Ellipses.append(new qucs::Ellips(-12,-12, 24, 24, QPen(Qt::blue,3)));
+  Texts.append(new Text(26, 6,"ITRN",Qt::blue,12.0,0.0,-1.0));
+  // pins
   Lines.append(new qucs::Line(-30,  0,-12,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 30,  0, 12,  0,QPen(Qt::darkBlue,2)));
-  
-  Lines.append(new qucs::Line(-12,  1,  1,-12,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line(-10,  6,  6,-10,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line( -7, 10, 10, -7,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line( -2, 12, 12, -2,QPen(Qt::darkGray,3)));
-  
-  Lines.append(new qucs::Line( -7,  0,  7,  0,QPen(Qt::blue,3)));
-  Lines.append(new qucs::Line(  6,  0,  0, -4,QPen(Qt::blue,3)));
-  Lines.append(new qucs::Line(  6,  0,  0,  4,QPen(Qt::blue,3)));
+  // diagonal strokes
+  Lines.append(new qucs::Line(-12,  1,  1,-12,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line(-10,  6,  6,-10,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line( -7, 10, 10, -7,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line( -2, 12, 12, -2,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  // arrow
+  Lines.append(new qucs::Line( -7,  0,  6,  0,QPen(Qt::blue,3, Qt::SolidLine, Qt::FlatCap)));
+  Polylines.append(new qucs::Polyline(
+    std::vector<QPointF>{{0, -4},{6, 0}, {0, 4}}, QPen(Qt::blue, 3, Qt::SolidLine, Qt::SquareCap, Qt::MiterJoin)));
 
   
   Ports.append(new Port( 30,  0));
@@ -95,7 +95,7 @@ Element* iTRNOISE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString iTRNOISE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString iTRNOISE::spice_netlist(bool)
