@@ -15,8 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "sp_customsim.h"
-#include "main.h"
-#include "misc.h"
 
 
 SpiceCustomSim::SpiceCustomSim()
@@ -24,25 +22,29 @@ SpiceCustomSim::SpiceCustomSim()
   isSimulation = true;
   Description = QObject::tr("Nutmeg script");
   Simulator = spicecompat::simNgspice | spicecompat::simSpiceOpus;
-
-  Texts.append(new Text(0, 0, Description, Qt::darkRed, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+104; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".CUSTOMSIM";
   Name  = "CUSTOM";
   SpiceModel = "CUSTOM";
 
   // The index of the first 4 properties must not changed. Used in recreate().
   Props.append(new Property("SpiceCode", "\n"
-                            "AC LIN 2000 100 10MEG\n"
-                            "let K=V(1)/V(2)\n", true,
+                            "AC DEC 100 1K 10MEG\n"
+                            "let K=V(out)/V(in)\n\n"
+                            "* Use mouse double click on device to edit code\n\n"
+                            "* Extra output\n"
+                            "* A custom prefix could be placed between # #\n"
+                            "* It will be prepended to all dataset variables\n"
+                            "write custom#ac1#.plot K\n\n"
+                            "* Scalars can be printed\n"
+                            "* They will be available in the dataset\n"
+                            "let Vout_max=vecmax(V(out))\n"
+                            "let KdB_max=db(vecmax(K))\n"
+                            "print Vout_max KdB_max > custom#ac1#.print\n",
+                            true,
                                          "Insert spice code here"));
-  Props.append(new Property("Vars","V(1);V(2)",false,"Vars to plot"));
-  Props.append(new Property("Outputs","Custom_ac.txt;Custom_tran.txt",false,"Extra outputs to parse"));
+  Props.append(new Property("Vars","V(out);V(in)",false,"Vars to plot"));
+  Props.append(new Property("Outputs","custom#ac1#.plot;custom#ac1#.print",false,"Extra outputs to parse"));
 
 }
 
