@@ -17,6 +17,7 @@
 #include "sp_func.h"
 #include "main.h"
 
+#include <QFontInfo>
 #include <QFontMetrics>
 
 SpiceFunc::SpiceFunc()
@@ -37,7 +38,7 @@ SpiceFunc::SpiceFunc()
   Lines.append(new qucs::Line(-xb, -yb, -xb,  yb,QPen(Qt::darkRed,2)));
   Lines.append(new qucs::Line(-xb,  yb,  xb+3,yb,QPen(Qt::darkRed,2)));
   Texts.append(new Text(-xb+4,  -yb-3, QObject::tr(".FUNC"),
-			QColor(0,0,0), 12.0));
+			QColor(0,0,0), QFontInfo(f).pixelSize()));
 
   x1 = -xb-3;  y1 = -yb-5;
   x2 =  xb+9; y2 =  yb+3;
@@ -71,7 +72,7 @@ Element* SpiceFunc::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString SpiceFunc::getExpression(bool)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QString s;
     s.clear();
