@@ -17,7 +17,9 @@
 #include "sp_nutmeg.h"
 #include "main.h"
 
+#include <QFontInfo>
 #include <QFontMetrics>
+#include <QRegularExpression>
 
 NutmegEquation::NutmegEquation()
 {
@@ -37,7 +39,7 @@ NutmegEquation::NutmegEquation()
   Lines.append(new qucs::Line(-xb, -yb, -xb,  yb,QPen(Qt::blue,2)));
   Lines.append(new qucs::Line(-xb,  yb,  xb+3,yb,QPen(Qt::blue,2)));
   Texts.append(new Text(-xb+4,  -yb-3, QObject::tr("Nutmeg"),
-			QColor(0,0,0), 12.0));
+			QColor(0,0,0), QFontInfo(f).pixelSize()));
 
   x1 = -xb-3;  y1 = -yb-5;
   x2 =  xb+9; y2 =  yb+3;
@@ -48,8 +50,7 @@ NutmegEquation::NutmegEquation()
   SpiceModel = "NutmegEq";
   Name  = "NutmegEq";
 
-  Props.append(new Property("Simulation","ac",true,
-                            "Used simulation [ac, tran, dc, disto, sp, fft, all]"));
+  Props.append(new Property("Simulation", "ALL", true, "Simulation name"));
   Props.append(new Property("y", "1", true));
 }
 
@@ -73,16 +74,22 @@ Element* NutmegEquation::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString NutmegEquation::getEquations(QString sim, QStringList &dep_vars)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QString s;
-    s.clear();
-    if (Props.at(0)->Value==sim) {
-        Property *pp = Props.first();
-        pp = Props.next();
-        for (;pp!=0;pp=Props.next()) {
-            s += QString("let %1 = %2\n").arg(pp->Name).arg(pp->Value);
-            dep_vars.append(pp->Name);
+    QRegularExpression sim_rx("^\\w+\\d+");
+    QString used_sim =  Props.at(0)->Value.toLower();
+    bool match = false;
+    if ( sim_rx.match(used_sim).hasMatch() )
+        match = sim == used_sim;
+    else
+        match = sim.startsWith(used_sim);
+    if ( match || used_sim == "all" ) {
+        auto pp = Props.begin();
+        pp++;
+        for ( ; pp != Props.end() ; ++pp) {
+            s += QString("let %1 = %2\n").arg((*pp)->Name).arg((*pp)->Value);
+          dep_vars.append((*pp)->Name);
         }
     }
     return s;
