@@ -17,6 +17,7 @@
 #include "sp_options.h"
 #include "main.h"
 
+#include <QFontInfo>
 #include <QFontMetrics>
 
 SpiceOptions::SpiceOptions()
@@ -37,7 +38,7 @@ SpiceOptions::SpiceOptions()
   Lines.append(new qucs::Line(-xb, -yb, -xb,  yb,QPen(Qt::darkRed,2)));
   Lines.append(new qucs::Line(-xb,  yb,  xb+3,yb,QPen(Qt::darkRed,2)));
   Texts.append(new Text(-xb+4,  -yb-3, QObject::tr(".OPTIONS"),
-			QColor(0,0,0), 12.0));
+			QColor(0,0,0), QFontInfo(f).pixelSize()));
 
   x1 = -xb-3;  y1 = -yb-5;
   x2 =  xb+9; y2 =  yb+3;
@@ -72,18 +73,18 @@ Element* SpiceOptions::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString SpiceOptions::getExpression(bool isXyce)
 {
-    if (isActive != COMP_IS_ACTIVE) return QString("");
+    if (isActive != COMP_IS_ACTIVE) return QString();
 
     QString s;
     s.clear();
     if (isXyce) {
         s += QString(".OPTIONS %1 ").arg(Props.at(0)->Value);
-        for (unsigned int i=1;i<Props.count();i++) {
+        for (int i=1;i<Props.count();i++) {
             s += QString(" %1 = %2 ").arg(Props.at(i)->Name).arg(Props.at(i)->Value);
         }
         s += "\n";
     } else {
-        for (unsigned int i=1;i<Props.count();i++) {
+        for (int i=1;i<Props.count();i++) {
             s += QString(".OPTION %1 = %2\n").arg(Props.at(i)->Name).arg(Props.at(i)->Value);
         }
     }
