@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "sp_sens.h"
-#include "main.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -24,20 +23,7 @@ SpiceSENS::SpiceSENS()
   isSimulation = true;
   Description = QObject::tr("DC sensitivity simulation");
   Simulator = spicecompat::simNgspice | spicecompat::simSpiceOpus;
-
-  QString  s = Description;
-  int a = s.indexOf(" ");
-  if (a != -1) s[a] = '\n';
-
-  Texts.append(new Text(0, 0, s.left(a), Qt::darkRed, QucsSettings.largeFontSize));
-  if (a != -1)
-    Texts.append(new Text(0, 0, s.mid(a+1), Qt::darkRed, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+104; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".SENS";
   Name  = "SENS";
   SpiceModel = ".SENS";
@@ -84,7 +70,7 @@ QString SpiceSENS::spice_netlist(bool isXyce)
         QString start = spicecompat::normalize_value(Props.at(2)->Value);
         QString stop = spicecompat::normalize_value(Props.at(3)->Value);
         QString step = spicecompat::normalize_value(Props.at(4)->Value);
-        QString output = "spice4qucs.ngspice.sens.dc.prn";
+        QString output = "spice4qucs." + Name.toLower() + ".ngspice.sens.dc.prn";
         s += QString("echo \"Start\">%1\n").arg(output);
         s += QString("let %1_start=%2\n").arg(sweepvar).arg(start);
         s += QString("let %1_sweep=%1_start\n").arg(sweepvar);
