@@ -15,7 +15,6 @@
  *                                                                         *
  ***************************************************************************/
 #include "sp_spectrum.h"
-#include "main.h"
 #include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
@@ -25,20 +24,7 @@ SpiceFFT::SpiceFFT()
   isSimulation = true;
   Description = QObject::tr("Spectrum analysis");
   Simulator = spicecompat::simNgspice | spicecompat::simSpiceOpus;
-
-  QString  s = Description;
-  int a = s.indexOf(" ");
-  if (a != -1) s[a] = '\n';
-
-  Texts.append(new Text(0, 0, s.left(a), Qt::darkBlue, QucsSettings.largeFontSize));
-  if (a != -1)
-    Texts.append(new Text(0, 0, s.mid(a+1), Qt::darkBlue, QucsSettings.largeFontSize));
-
-  x1 = -10; y1 = -9;
-  x2 = x1+104; y2 = y1+59;
-
-  tx = 0;
-  ty = y2+1;
+  initSymbol(Description);
   Model = ".FFT";
   Name  = "FFT";
   SpiceModel = ".FFT";
@@ -49,6 +35,7 @@ SpiceFFT::SpiceFFT()
   Props.append(new Property("Window","hanning", true, "Window type "
                                      "[none,rectangular,bartlet,blackman,hanning,hamming,gaussian,flattop]"));
   Props.append(new Property("Order","2",false,"Order of the Gaussian window"));
+  Props.append(new Property("Tstart","0",false,"Transient starting time"));
 
 }
 
@@ -81,10 +68,12 @@ QString SpiceFFT::spice_netlist(bool isXyce)
     double bw = num*fac;
     misc::str2num(getProperty("dF")->Value,num,unit,fac);
     double df = num*fac;
-    double tstop = 1.0/df;
+    misc::str2num(getProperty("Tstart")->Value,num,unit,fac);
+    double tstart = num*fac;
+    double tstop = 1.0/df + tstart;
     double tstep = 1.0/(2*bw);
     QString win = getProperty("Window")->Value;
-    s =  QString("tran %1 %2 0\n").arg(tstep).arg(tstop);
+    s =  QString("tran %1 %2 %3\n").arg(tstep).arg(tstop).arg(tstart);
     s += QString("set specwindow=%1\n").arg(win);
     if (win == "gaussian") {
         s += QString("set specwindoworder=%1\n")
