@@ -20,7 +20,6 @@
  ***************************************************************************/
 #include "vTRNOISE.h"
 #include "node.h"
-#include "misc.h"
 #include "extsimkernels/spicecompat.h"
 
 
@@ -30,15 +29,16 @@ vTRNOISE::vTRNOISE()
   Simulator = spicecompat::simSpice;
 
   // normal voltage source symbol
-  Arcs.append(new qucs::Arc(-12,-12, 24, 24, 0, 16*360,QPen(Qt::blue,3)));
-   Texts.append(new Text(36, 4,"VTRN",Qt::blue,10.0,0.0,-1.0)); 
+  Ellipses.append(new qucs::Ellips(-12,-12, 24, 24, QPen(Qt::blue,3)));
+  Texts.append(new Text(26, 6,"VTRN",Qt::blue,12.0,0.0,-1.0));
+  // pins
   Lines.append(new qucs::Line(-30,  0,-12,  0,QPen(Qt::darkBlue,2)));
   Lines.append(new qucs::Line( 30,  0, 12,  0,QPen(Qt::darkBlue,2)));
-  
-  Lines.append(new qucs::Line(-12,  1,  1,-12,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line(-10,  6,  6,-10,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line( -7, 10, 10, -7,QPen(Qt::darkGray,3)));
-  Lines.append(new qucs::Line( -2, 12, 12, -2,QPen(Qt::darkGray,3)));
+  // diagonal strokes
+  Lines.append(new qucs::Line(-12,  1,  1,-12,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line(-10,  6,  6,-10,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line( -7, 10, 10, -7,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
+  Lines.append(new qucs::Line( -2, 12, 12, -2,QPen(Qt::darkGray,3, Qt::SolidLine, Qt::FlatCap)));
 
   
   Ports.append(new Port( 30,  0));
@@ -91,7 +91,7 @@ Element* vTRNOISE::info(QString& Name, char* &BitmapFile, bool getNewOne)
 
 QString vTRNOISE::netlist()
 {
-    return QString("");
+    return QString();
 }
 
 QString vTRNOISE::spice_netlist(bool)
